%AddWelfare
%Script that computes welfare measures to analyze the effect of mergers.
%The script has to be executed after the file with the merger results are
%loaded.
% It creates the following variables:
%A. Consumer Average Costs:
% Pre-merger
% CWp_intercept: Intercept
% CWp_cscm: Coefficient on (cs-cm)
% CWp_cscm2: Coefficient on (cs-cm)^2
% CWp_sig2: Coefficient on \sigma_{c}^2 (variance of costs)
% After-Merger
% CWm_intercept: Intercept
% CWm_cscm: Coefficient on (cs-cm)
% CWm_cscm2: Coefficient on (cs-cm)^2
% CWm_sig2: Coefficient on \sigma_{c}^2 (variance of costs)
% Effect of the merger
% CW_intercept=CWm_intercept-CWp_intercept;
% CW_cscm=CWm_cscm-CWp_cscm;
% CW_cscm2=CWm_cscm2-CWp_cscm2;
% CW_sig2=CWm_sig2-CWp_sig2;
%B. Total Average Costs:
% Pre-merger
% TCp_intercept: Intercept
% TCp_cscm: Coefficient on (cs-cm)
% TCp_cscm2: Coefficient on (cs-cm)^2
% TCp_sig2: Coefficient on \sigma_{c}^2 (variance of costs)
% After-Merger
% TCm_intercept: Intercept
% TCm_cscm: Coefficient on (cs-cm)
% TCm_cscm2: Coefficient on (cs-cm)^2
% TCm_sig2: Coefficient on \sigma_{c}^2 (variance of costs)
% Effect of the merger
% TC_intercept=CWm_intercept-CWp_intercept;
% TC_cscm=CWm_cscm-CWp_cscm;
% TC_cscm2=CWm_cscm2-CWp_cscm2;
% TC_sig2=CWm_sig2-CWp_sig2;
%C. Share-Weighted Average Prices.
% Pre-merger
% APp_intercept: Intercept
% APp_cscm: Coefficient on (cs-cm)
% APp_cscm2: Coefficient on (cs-cm)^2
% APp_sig2: Coefficient on \sigma_{c}^2 (variance of costs)
% After-Merger
% APm_intercept: Intercept
% APm_cscm: Coefficient on (cs-cm)
% APm_cscm2: Coefficient on (cs-cm)^2
% APm_sig2: Coefficient on \sigma_{c}^2 (variance of costs)
% Effect of the merger
% AP_intercept=CWm_intercept-CWp_intercept;
% AP_cscm=CWm_cscm-CWp_cscm;
% AP_cscm2=CWm_cscm2-CWp_cscm2;
% AP_sig2=CWm_sig2-CWp_sig2;
% Dependent Files: <file with the results of mergerpass.m (or
% mergerpass_serial.m) loaded in the memory. See exec_mergerpass1.m to see
% the names variables should have>
% Previous name: Code/MergerEffect/welfaremeasures.m


%% Unweighted Mean Price equilibrium 
%after merger
MPm_intercept=mp_intercept;  % Intercept
MPm_cscm=mp_cscm; % Coefficient on  (cs-cm)

%pre merger
MPp_intercept=r.pss0; % Intercept
MPp_cscm=0; % Coefficient on  (cs-cm)

%% Covariance
COm_cscm=cpc_cscm;  % Coefficient on  (cs-cm)
COm_cscm2=cpc_cscm2; % Coefficient on  (cs-cm)^2 
COm_sig2=cpc_sig2; % Coefficient on  var(c_s)

COp_cscm=0; 
COp_cscm2=0;
COp_sig2=r.gammaeq;

%% Variance
VPm_intercept=vp_intercept;
VPm_cscm=vp_cscm;
VPm_cscm2=vp_cscm2;
VPm_sig2=vp_sig2;

VPp_intercept=0;
VPp_cscm=0;
VPp_cscm2=0;
VPp_sig2=r.gammaeq.^2;

%% Weight on consumer welfare
CW_varp=-(1+g_g.*(1-dc_g.^2.*s_g.^2)+2*s_g.*(1+dc_g.*s_g))/2./(1+g_g); %Coefficient on price variance in Eq 19.
C_intercept=(4+4.*g_g).^(-1).*(1+g_g+2.*s_g+(-1).*s_g.^2); %Intercept in Eq 19.
%Pre-merger
CWp_intercept=MPp_intercept+CW_varp.*(VPp_intercept)+C_intercept;
CWp_cscm=MPp_cscm+CW_varp.*(VPp_cscm);
CWp_cscm2=CW_varp.*(VPp_cscm2);
CWp_sig2=CW_varp.*(VPp_sig2);
%After-Merger
CWm_intercept=MPm_intercept+CW_varp.*(VPm_intercept)+C_intercept;
CWm_cscm=MPm_cscm+CW_varp.*(VPm_cscm);
CWm_cscm2=CW_varp.*(VPm_cscm2);
CWm_sig2=CW_varp.*(VPm_sig2);
%Effect of the merger
CW_intercept=CWm_intercept-CWp_intercept;
CW_cscm=CWm_cscm-CWp_cscm;
CW_cscm2=CWm_cscm2-CWp_cscm2;
CW_sig2=CWm_sig2-CWp_sig2;


%% Weight on total costs
TC_varp=(1+g_g.*(1+dc_g.*s_g).^2)/2./(1+g_g); %Coefficient on price variance in Eq 18.
TC_covcp=-(1+g_g+s_g+dc_g.*s_g.*g_g+dc_g.*s_g.^2)./(1+g_g); %Coefficient on covariance in Eq 18.
C_intercept; %Intercept in Eq 18.
%Pre-Merger
TCp_intercept=TC_varp.*(VPp_intercept)+C_intercept;
TCp_cscm=TC_varp.*(VPp_cscm)+TC_covcp.*(COp_cscm);
TCp_cscm2=TC_varp.*(VPp_cscm2)+TC_covcp.*(COp_cscm2);
TCp_sig2=TC_varp.*(VPp_sig2)+TC_covcp.*(COp_sig2);
%After-Merger
TCm_intercept=TC_varp.*(VPm_intercept)+C_intercept;
TCm_cscm=TC_varp.*(VPm_cscm)+TC_covcp.*(COm_cscm);
TCm_cscm2=TC_varp.*(VPm_cscm2)+TC_covcp.*(COm_cscm2);
TCm_sig2=TC_varp.*(VPm_sig2)+TC_covcp.*(COm_sig2);
%Effect of Merger
TC_intercept=TCm_intercept-TCp_intercept;
TC_cscm=TCm_cscm-TCp_cscm;
TC_cscm2=TCm_cscm2-TCp_cscm2;
TC_sig2=TCm_sig2-TCp_sig2;

%% Weight on Average Prices
AP_varp=-(1+(g_g+s_g).*(1+dc_g.*s_g))./(1+g_g); %Coefficient on price variance in Eq 18.
%Pre-merger
APp_intercept=MPp_intercept+AP_varp.*(VPp_intercept);
APp_cscm=MPp_cscm+AP_varp.*(VPp_cscm);
APp_cscm2=AP_varp.*(VPp_cscm2);
APp_sig2=AP_varp.*(VPp_sig2);
%After-Merger
APm_intercept=MPm_intercept+AP_varp.*(VPm_intercept);
APm_cscm=MPm_cscm+AP_varp.*(VPm_cscm);
APm_cscm2=AP_varp.*(VPm_cscm2);
APm_sig2=AP_varp.*(VPm_sig2);
%Effect of the merger
AP_intercept=APm_intercept-APp_intercept;
AP_cscm=APm_cscm-APp_cscm;
AP_cscm2=APm_cscm2-APp_cscm2;
AP_sig2=APm_sig2-APp_sig2;
