% Figures2and3.m   Generates Figures 2 and 3 in the paper
% Description: See notes in the figures.
% Output: Figure 2 'rangePrices.bmp', Figure 3(a) 'rangeeffCW.bmp' and
% Figure 3(b) 'rangeeffTC.bmp'

% Previous name: Code/MergerEffect/RegressionTables1.m
% Dependent files: mergerpassm.mat 

clear
load mergerpass1.mat
AddWelfare
effonprice=AP_intercept;

%% Figure 2

index=(s_g==0); %index=(s_g==0);
un=unique(n_g);
minP=zeros(size(un));
maxP=minP;

h=figure(2);
cla;
hold on
for i=3:numel(maxP)-2
    minP(i)=min(effonprice(n_g==un(i)));
    maxP(i)=max(effonprice(n_g==un(i)));
    points=(index.*(n_g==un(i)))==1;
    
    line([un(i) un(i)],[minP(i) maxP(i)],'LineWidth',3,'Color','b')
    scatter(un(i)*ones(sum(points),1),effonprice(points),100,'xk');
    if un(i)==6, disp(effonprice(points)); end
end
xlabel('J');
ylabel('Average Price(post)- Average Price(pre)');
set(gca,'XTick',un(2:numel(maxP)-1))
hold off
set(gca,'XLim',[4.5 10.5])
saveas(h,'rangePrices.bmp')


%% Figure 3 (a,b)

index=(s_g==0);
un=unique(n_g);
cs_cm=0.5; sig2=2*(n_g-2)./(n_g-1)./(n_g).*cs_cm^2;
% Consumer Costs
minCW0=zeros(size(un));
maxCW0=minCW0;
minCWP=minCW0;
maxCWP=minCW0;
minCWN=minCW0;
maxCWN=minCW0;

h=figure(2);
cla;
hold on
for i=3:numel(minCW0)-2
    minCW0(i)=min(CW_intercept(n_g==un(i)));
    maxCW0(i)=max(CW_intercept(n_g==un(i)));
    minCWN(i)=min(CW_intercept(n_g==un(i))-CW_cscm(n_g==un(i))*cs_cm+CW_cscm2(n_g==un(i))*cs_cm^2+CW_sig2(n_g==un(i)).*sig2(n_g==un(i)));
    maxCWN(i)=max(CW_intercept(n_g==un(i))-CW_cscm(n_g==un(i))*cs_cm+CW_cscm2(n_g==un(i))*cs_cm^2+CW_sig2(n_g==un(i)).*sig2(n_g==un(i)));
    minCWP(i)=min(CW_intercept(n_g==un(i))+CW_cscm(n_g==un(i))*cs_cm+CW_cscm2(n_g==un(i))*cs_cm^2+CW_sig2(n_g==un(i)).*sig2(n_g==un(i)));
    maxCWP(i)=max(CW_intercept(n_g==un(i))+CW_cscm(n_g==un(i))*cs_cm+CW_cscm2(n_g==un(i))*cs_cm^2+CW_sig2(n_g==un(i)).*sig2(n_g==un(i)));
    points=(index.*(n_g==un(i)))==1;
    
    line([un(i) un(i)],[minCW0(i) maxCW0(i)],'LineWidth',3,'Color','b')
    scatter(un(i)*ones(sum(points),1),CW_intercept(points),100,'xk');
    line([un(i)+0.1 un(i)+0.1],[minCWN(i) maxCWN(i)],'LineWidth',3,'Color','g')
    scatter((un(i)+0.1)*ones(sum(points),1),CW_intercept(points)-CW_cscm(points)*cs_cm+CW_cscm2(points)*cs_cm^2+CW_sig2(points).*sig2(points),100,'xk');
    line([un(i)-0.1 un(i)-0.1],[minCWP(i) maxCWP(i)],'LineWidth',3,'Color','r')
    scatter((un(i)-0.1)*ones(sum(points),1),CW_intercept(points)+CW_cscm(points)*cs_cm+CW_cscm2(points)*cs_cm^2+CW_sig2(points).*sig2(points),100,'xk');
    if un(i)==5
        disp([CW_intercept(points)-CW_cscm(points)*cs_cm+CW_cscm2(points)*cs_cm^2+CW_sig2(points).*sig2(points)
            CW_intercept(points)
            CW_intercept(points)+CW_cscm(points)*cs_cm+CW_cscm2(points)*cs_cm^2+CW_sig2(points).*sig2(points)]); 
    end

end
xlabel('J');
ylabel('Consumers Cost (post)- Consumers Cost (pre)');

hold off
set(gca,'XLim',[4.5 10.5])
saveas(h,'rangeeffCW.bmp')

% Total Costs
minTC0=minCW0;
maxTC0=minTC0;
minTCP=minTC0;
maxTCP=minTC0;
minTCN=minTC0;
maxTCN=minTC0;

h=figure(3);
cla;
hold on
for i=3:numel(minTC0)-2
    minTC0(i)=min(TC_intercept(n_g==un(i)));
    maxTC0(i)=max(TC_intercept(n_g==un(i)));
    minTCN(i)=min(TC_intercept(n_g==un(i))-TC_cscm(n_g==un(i))*cs_cm+TC_cscm2(n_g==un(i))*cs_cm^2+TC_sig2(n_g==un(i)).*sig2(n_g==un(i)));
    maxTCN(i)=max(TC_intercept(n_g==un(i))-TC_cscm(n_g==un(i))*cs_cm+TC_cscm2(n_g==un(i))*cs_cm^2+TC_sig2(n_g==un(i)).*sig2(n_g==un(i)));
    minTCP(i)=min(TC_intercept(n_g==un(i))+TC_cscm(n_g==un(i))*cs_cm+TC_cscm2(n_g==un(i))*cs_cm^2+TC_sig2(n_g==un(i)).*sig2(n_g==un(i)));
    maxTCP(i)=max(TC_intercept(n_g==un(i))+TC_cscm(n_g==un(i))*cs_cm+TC_cscm2(n_g==un(i))*cs_cm^2+TC_sig2(n_g==un(i)).*sig2(n_g==un(i)));
    points=(index.*(n_g==un(i)))==1;
    
    line([un(i) un(i)],[minTC0(i) maxTC0(i)],'LineWidth',3,'Color','b')
    scatter(un(i)*ones(sum(points),1),TC_intercept(points),100,'xk');
    line([un(i)+0.1 un(i)+0.1],[minTCN(i) maxTCN(i)],'LineWidth',3,'Color','g')
    scatter((un(i)+0.1)*ones(sum(points),1),TC_intercept(points)-TC_cscm(points)*cs_cm+TC_cscm2(points)*cs_cm^2+TC_sig2(points).*sig2(points),100,'xk');
    line([un(i)-0.1 un(i)-0.1],[minTCP(i) maxTCP(i)],'LineWidth',3,'Color','r')
    scatter((un(i)-0.1)*ones(sum(points),1),TC_intercept(points)+TC_cscm(points)*cs_cm+TC_cscm2(points)*cs_cm^2+TC_sig2(points).*sig2(points),100,'xk');
    if un(i)==5
        disp([TC_intercept(points)-TC_cscm(points)*cs_cm+TC_cscm2(points)*cs_cm^2+TC_sig2(points).*sig2(points)
            TC_intercept(points)
            TC_intercept(points)+TC_cscm(points)*cs_cm+TC_cscm2(points)*cs_cm^2+TC_sig2(points).*sig2(points)]); 
    end

end
xlabel('J');
ylabel('Total Cost (post)- Total Cost (pre)');

hold off
set(gca,'XLim',[4.5 10.5])
saveas(h,'rangeeffTC.bmp')

