function [omega_m,phi_m,lambda1,lambda2,mp_intercept,mp_cscm,...
    cpc_cscm,cpc_cscm2,cpc_sig2,vp_intercept,vp_cscm,vp_cscm2,...
    vp_sig2,r]=mergerpass(s_g,df_g,dc_g,n_g,g_g)
% mergerpass  Computes the equilibrium after a merger from J
% single product firms with symmetric demand structure to J-2 single
% product firms and one merged entity. It computes multiple scenarios
% using the parallel computing feature in Matlab.
%function [omega_m,phi_m,lambda1,lambda2,mp_intercept,mp_cscm,...
%    cpc_cscm,cpc_cscm2,cpc_sig2,vp_intercept,vp_cscm,vp_cscm2,...
%    vp_sig2]=mergerpass(s_g,df_g,dc_g,n_g,g_g)
% s_g: vector. Switching cost (Length of segment=1).
% df_g: vector. Firms' effective discount rate.
% dc_g: vector. Consumers' discount rate
% n_g: vector. Number of firms
% g_g: scalar. Size of the young cohort
% Scenario i is constructed by the i-th element in each of these vectors.
% Output:
%   omega_m,phi_m,lambda1,lambda2: vectors. See paper.
%   Mean price:
%   mp_intercept: vector. pss0, the average price when costs are 0.
%   mp_cscm: vector. coefficient on (cs-cm)
%   Covariance between prices and covariance:
%   cpc_cscm: vector. coefficient on (cs-cm)
%   cpc_cpcm2: vector. coefficient on (cs-cm)^2
%   cpc_sig2: vector. coefficient on \sigma_{c}^2
%   Price Variance:
%   vp_intercept: vector. intercept of the variance after the merger.
%   vp_cscm: vector. coefficient on (cs-cm)
%   vp_cpcm2: vector. coefficient on (cs-cm)^2
%   vp_sig2: vector. coefficient on \sigma_{c}^2
%It also returns a structure r, which resutls from calling SingleProduct.m
% Dependent files: SingleProduct.m,findMPNEg.m

iter=numel(s_g);
omega_m=zeros(iter,1);
phi_m=zeros(iter,1);
lambda1=zeros(iter,1);
lambda2=zeros(iter,1);
%Mean prices:
mp_intercept=zeros(iter,1);
mp_cscm=zeros(iter,1); 
%Covariance prices and costs
cpc_cscm=zeros(iter,1); 
cpc_cscm2=zeros(iter,1); 
cpc_sig2=zeros(iter,1); 
%Variance of prices:
vp_intercept=zeros(iter,1); 
vp_cscm=zeros(iter,1); 
vp_cscm2=zeros(iter,1); 
vp_sig2=zeros(iter,1); 
[beta,r]=SingleProduct(s_g,df_g,dc_g,n_g,g_g);
xi0=r.xi0;
xi1=r.xi1;
matlabpool
parfor i=1:iter

    s=s_g(i);
    N=n_g(i);
    dc=dc_g(i);
    g=g_g(i);
    df=df_g(i);
    betai=beta(i);
    disp([s N dc g df]);
   
    B=ones(N,N)*(xi0(i)/(1-xi1(i)))+eye(N)*betai;

    fmat=ones(N)-tril(triu(ones(N)));
    fmat=fmat/(sum(sum(fmat)))*2;
    fmat2=fmat(2:N,2:N);
    fmat2(1,:)=fmat2(1,:)+fmat(1,2:N);
    fmat2(:,1)=fmat2(:,1)+fmat(2:N,1);
    fmat2(1,1)=fmat2(1,1)/2;
    free=1-fmat2(1,1);
    ft=ones(N,1)';

    % Matrix that transforms shares in the general model to shares among
    % the free consumers;
    Qm=[ones(1,2) -ones(1,N-2)*(1-free)/free;zeros(N-2,2) eye(N-2)/free];
    ft2=ft;
    ft2(1)=ft(1)+2;
    ft2(2)=ft(2)+1;
    ft2=ft2(1:length(ft2)-1);
    ft2=4-ft2;
  
[Pnc ssnc Pdistn mdistn]=findMPNEg(fmat2,[0 0 0],s,dc,df,g,ft2,B(2:N,2:N));
%disp('1/3')
[Pms ssms Pdistn mdistn]=findMPNEg(fmat2,[-1 0 0],s,dc,df,g,ft2,Pnc);
%disp('2/3')
[Pns ssms Pdistn mdistn]=findMPNEg(fmat2,[0 -1 0],s,dc,df,g,ft2,Pnc);
%disp('Done')
col1=Pnc(:,1)-Pms(:,1); %effect of the merged entity cost
head=Pnc(1,1)-Pns(1,1); %effect of small firms' cost of merged entity
diva=Pnc(2,1)-Pns(2,1); %effect of small firms' cost on itself
Ea=eye(N-2,N-2)*diva;

if N>3
    ofdi=Pnc(3,1)-Pns(3,1); %effect of small firms' cost on other small firms
    Ea=Ea+(ones(N-2,N-2)-eye(N-2,N-2))*ofdi;
end
Ea=[repmat(head,1,N-2);Ea];
Em=[col1/2 col1/2 Ea];
Em=[Em(1,:); Em]; %OK

Bm=Pnc*Qm;
Bm=[Bm(1,:); Bm];
M=eye(N)-ones(N)/N;m=ones(N,1)/N;
invQ=(eye(N)+(1+dc*s)/(N-1)*Bm*M); %inverse Q
% Mean price:
m0=m'/(invQ)*Bm*m; %Price intercept (pss0m)
m1=m'/(invQ)*Em; %eta'QE
wm=m1(1);
% m1=[1/n,...,1/n];

% Covariace and Variance price:
MQBeta=M/invQ*Bm*m;
MQE=M/invQ*Em;
phim=MQBeta(1);
if max(max(abs(MQE-MQE')))>1e-9, disp('Q is not symmetric'); end
[vp,d]=eig((MQE+MQE')/2);
eig2=0;eig1=0;
for q=1:N;
    if abs(d(q,q))>1E-8;
        if abs(corr2(vp(:,q),MQBeta))>1-1E-8;
            eig1=d(q,q);
        else
            eig2=d(q,q);
        end
    end
end

% Output:
omega_m(i)=wm;
phi_m(i)=phim;
lambda1(i)=eig1;
lambda2(i)=eig2;

%Mean prices:
mp_intercept(i)=m0;
mp_cscm(i)=2*(1/N-wm);

%Covariance prices and costs
cpc_cscm(i)=-2*phim/(N-1);
cpc_cscm2(i)=-2*(N-2)/N/(N-1)*(eig2-eig1);
cpc_sig2(i)=eig2;

%Variance of prices:
vp_intercept(i)=2*N*phim^2/(N-2)/(N-1);
vp_cscm(i)=-4*phim*eig1/(N-1);
vp_cscm2(i)=-2*(N-2)/N/(N-1)*(eig2^2-eig1^2);
vp_sig2(i)=eig2^2;


%  %Check Variance of prices at s=0 (Eq 40):
%  intercept=(N-1)/(2*(N-2)*N^3);[intercept-vp_intercept]
%  coefondcscm=(1-N)/N^3;[coefondcscm-vp_cscm]
%  coefondcscm2=-(N-2)*(N-1)*(4*N-1)/(2*N^3*(2*N-1)^2);[coefondcscm2-vp_cscm2]
%  coefonsigma2=(N-1)^2/(1-2*N)^2;[coefonsigma2-vp_sig2]
% %Check Cov prices and costs at s=0 (Eq 40):
%  coefondcscm=-1/N^2;[coefondcscm-cpc_cscm]
%  coefondcscm2=-(N-2)/((2*N-1)*N^2);[coefondcscm2-cpc_cscm2]
%  coefonsigma2=(N-1)/(2*N-1);[coefonsigma2-cpc_sig2]

% Check with example
check=false;
if check
for rep=1:5
    c=rand(N,1); c(1)=c(2); cdem=(c-mean(c)); 
    p=invQ\Bm*m+invQ\Em*c; pdem=(p-mean(p));
    sigc2=cdem'*cdem/(N-1); sigp2=pdem'*pdem/(N-1); sigpc=pdem'*cdem/(N-1);
    cscm=mean(c(3:N))-c(1);
    %mean price
    if mean(p)-(mp_intercept(i)+mp_cscm(i)*cscm+mean(c))>1e-9, disp('mean p'); end
    %var price
    if sigp2-(vp_intercept(i)+vp_cscm(i)*cscm+vp_cscm2(i)*cscm^2+vp_sig2(i)*sigc2)>1e-9, disp('var p'); end
    %cov price cost
    if sigpc-(cpc_cscm(i)*cscm+cpc_cscm2(i)*cscm^2+cpc_sig2(i)*sigc2)>1e-9, disp('cov pc'); end
end
end
end



