
function plot5in1(g,n,dc,df,s)
% PLOT5IN1   Generates a figure similar to Figure 1 in the paper: the
% equilibrum in the case of single product firms (N=J).
%
% Plot5in1(g,n,dc,df,s) generates the figure using the following baseline
% dynamic parameters:
% g: size of the young cohort where old=1. Parameter g in the paper
% n: number of firms/products N=J. Parameter N (or J) in the paper.
% dc: Consumers' discount rate. \delta_{c} in the paper.
% df: Firms' "effective" discount rate. \delta_{f} in the paper.
% s: switching costs. s=s/L in the paper, where L is the lenght of each
% segment which is normalized to 1.
% The default parameters are: g=1;n=5;dc=0.7;df=0.5;s=0.4. Figure 1 is
% reproduced just calling plot5in1 with no arguments.
%
% Output: A bmp file "fig1dim_del_%s.bmp", where %s summarizes the baseline
% parameters.
%
% Previous name: Code/SymmetricCase/plot5in1_new.m
% Dependent files: SingleProduct.m
disp('This function will create a figure in the current directory, Set path or change dir!');
disp('Press any key to continue');
pause;

if nargin < 1;g=1;end
if nargin < 2;n=5;end
if nargin < 3;dc=0.7;end
if nargin < 4;df=0.5;end
if nargin < 5;s=0.4;end

g_cs=0.01:0.01:2; %1
n_cs=2:29; %2
dc_cs=0.01:0.01:0.99; %3
df_cs=0.01:0.01:0.99; %4
s_cs=0.01:0.01:0.99; %5

% Code;
h=figure(1);
close(h);
h=figure(1);
scrsz=get(0,'ScreenSize');
set(h,'Position',scrsz);
[beta,result]=SingleProduct(s,df,dc,n,g_cs);
price=result.pss0;
expc=price+result.CACcons;
%line(g_cs,price.*(1-c1-c2)-0.1*(c1+c2));
subplot(3,2,2)
[AX1,H11,H21] =plotyy(g_cs,price,g_cs,expc,'plot');
set(H11,'LineStyle','-')
set(H21,'LineStyle','--')
%line(g_cs,(expc-price));
xlabel('(b) Market Growth Rate')
%ylabel('Price')
%axis([min(g_cs) max(g_cs) 0.5 1.1])
pax=[min(price) max(price)];
cax=[min(expc) max(expc)];
linkaxes([AX1(1) AX1(2)],'x');

%
%

[beta,result]=SingleProduct(s,df,dc,n_cs,g);
price=result.pss0;
expc=price+result.CACcons;
%scatter(n_cs,price.*(1-c1-c2)-0.1*(c1+c2));
subplot(3,2,1)
[AX2,H12,H22] =plotyy(n_cs,price,n_cs,expc,'plot');
set(H12,'LineStyle','-')
set(H22,'LineStyle','--')
xlabel('(a) Number of firms: constant L')
%ylabel('Price')
axis([min(n_cs) max(n_cs)  0.5 1.1])
pax=[min([price(:);pax(1)]) max([price(:);pax(2)])];
cax=[min([expc(:);cax(1)]) max([expc(:);cax(2)])];
linkaxes([AX2(1) AX2(2)],'x');


[beta,result]=SingleProduct(s,df,dc_cs,n,g);
price=result.pss0;
expc=price+result.CACcons;
subplot(3,2,3)
%line(dc_cs,price.*(1-c1-c2)-0.1*(c1+c2));
[AX3,H13,H23] =plotyy(dc_cs,price,dc_cs,expc,'plot');
set(H13,'LineStyle','-')
set(H23,'LineStyle','--')
xlabel('(c) Discount Rate: Consumers')
%ylabel('Price')
%axis([min(dc_cs) max(dc_cs)  0.5 1.1])
pax=[min([price(:);pax(1)]) max([price(:);pax(2)])];
cax=[min([expc(:);cax(1)]) max([expc(:);cax(2)])];
linkaxes([AX3(1) AX3(2)],'x');


[beta,result]=SingleProduct(s,df_cs,dc,n,g);
price=result.pss0;
expc=price+result.CACcons;
subplot(3,2,4)
[AX4,H14,H24] =plotyy(df_cs,price,df_cs,expc,'plot');
%line(df_cs,price.*(1-c1-c2)-0.1*(c1+c2));
set(H14,'LineStyle','-')
set(H24,'LineStyle','--')
xlabel('(d) Discount Rate: Firms')
%ylabel('Price')
axis([min(df_cs) max(df_cs) 0.5 1.1])
pax=[min([price(:);pax(1)]) max([price(:);pax(2)])];
cax=[min([expc(:);cax(1)]) max([expc(:);cax(2)])];

linkaxes([AX4(1) AX4(2)],'x');

subplot(3,2,5)
[beta,result]=SingleProduct(s_cs,df,dc,n,g);
price=result.pss0;
expc=price+result.CACcons;
[AX5,H15,H25] =plotyy(s_cs,price,s_cs,expc,'plot');
set(H15,'LineStyle','-')
set(H25,'LineStyle','--')
%line(s_cs,price.*(1-c1-c2)-0.1*(c1+c2));
%line(dc_cs,expc-price);
xlabel('(e) Switching costs / Length')
%ylabel('Price')

%axis([min(s_cs) max(s_cs.*(1-c1-c2)-0.1*(c1+c2)) 0.5 1.1])
pax=[min([price(:);pax(1)]) max([price(:);pax(2)])];
cax=[min([expc(:);cax(1)]) max([expc(:);cax(2)])];
linkaxes([AX5(1) AX5(2)],'x');
linkaxes([AX4(1) AX1(1) AX2(1) AX3(1) AX5(1)],'y');
linkaxes([AX4(2) AX1(2) AX2(2) AX3(2) AX5(2)],'y');
set(AX1(1),'YLim',pax)
set(AX1(2),'YLim',cax)
set(AX1(1),'YAxisLocation','left')
dec=2;
bpax=[ceil(pax(1)*10^dec)/10^dec floor(pax(2)*10^dec)/10^dec];
bcax=[ceil(cax(1)*10^dec)/10^dec floor(cax(2)*10^dec)/10^dec];
set(AX1(1),'YTickMode','auto')
set(AX1(2),'YTickMode','auto')
set(AX2(1),'YTickMode','auto')
set(AX2(2),'YTickMode','auto')
set(AX3(1),'YTickMode','auto')
set(AX3(2),'YTickMode','auto')
set(AX4(1),'YTickMode','auto')
set(AX4(2),'YTickMode','auto')
set(AX5(1),'YTickMode','auto')
set(AX5(2),'YTickMode','auto')
%subplot(3,2,6)
annotation('textbox',[0.6 0.3 0.4 0],'LineStyle','none','string','Parameter Values:')
annotation('textbox',[0.65 0.275 0.4 0],'LineStyle','none','string',['Number of firms (N) = ' num2str(n)])
annotation('textbox',[0.65 0.25 0.4 0],'LineStyle','none','string',['Market growth (g) = ' num2str(g)])
annotation('textbox',[0.65 0.225 0.4 0],'LineStyle','none','string',['Discount Rate, consumers (\delta_{c}) = ' num2str(dc)])
annotation('textbox',[0.65 0.2 0.4 0],'LineStyle','none','string',['Discount Rate, firms (\delta_{f}) = ' num2str(df)])
annotation('textbox',[0.65 0.175 0.4 0],'LineStyle','none','string',['Switching Costs (s) =' num2str(s)])
annotation('textbox',[0.6 0.15 0.4 0],'LineStyle','none','string','Steady state prices: solid line, left y-axis')
annotation('textbox',[0.6 0.125 0.4 0],'LineStyle','none','string','Consumer costs: broken line, right y-axis')
saveas1=['fig1dim_del ' num2str(n) '_' num2str(round(g*100)) '_' num2str(round(dc*100)) '_' num2str(round(df*100)) '_' num2str(round(s*100)) '.bmp'];
saveas(h,saveas1)

