(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    113106,       3372]
NotebookOptionsPosition[    103940,       3069]
NotebookOutlinePosition[    104280,       3084]
CellTagsIndexPosition[    104237,       3081]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Welfare Analysis", "Title",
 CellChangeTimes->{{3.505167922708*^9, 3.505167960094*^9}, {
  3.5484350376659164`*^9, 3.548435041201119*^9}}],

Cell["\<\
There are three types of costs in our model: switching, transportation and \
production costs. If firms have heterogeneous costs the resulting steady \
state allocation will depend on the parameter configuration and so will \
welfare. Low cost firms will set lower prices and will have a larger market \
share. This will increase the allocative efficiency relative to the case of \
homogeneous costs. However, only a fraction of potential efficiency gains \
will be realized because the pass-trough from costs to prices is less than \
perfect because of strategic reasons.\
\>", "Text",
 CellChangeTimes->{{3.505167963252*^9, 3.5051680787539997`*^9}, {
   3.505168215442*^9, 3.5051686958929996`*^9}, {3.505168727587*^9, 
   3.505168786382*^9}, 3.5484350350937696`*^9, {3.548435081475423*^9, 
   3.548435098671406*^9}}],

Cell[CellGroupData[{

Cell["Prelims", "Subsection",
 CellChangeTimes->{{3.5052355691497526`*^9, 3.5052355703327527`*^9}}],

Cell["\<\
In Appendix D in the paper we derive consumer's expected prices plus \
transportation and switching costs  for any set of prices. Let: Ww(L,a,b)=E \
min(\[Theta]+a,L-\[Theta]+b)\
\>", "Text",
 CellChangeTimes->{{3.5051521065955524`*^9, 3.5051521147025523`*^9}, {
  3.5051577970275526`*^9, 3.505157839257552*^9}, {3.505168813407*^9, 
  3.505168902797*^9}, {3.505175548112*^9, 3.505175560429*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ww", "[", 
   RowBox[{"L_", ",", "a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{
   FractionBox["L", "4"], "+", 
   FractionBox[
    RowBox[{"(", 
     RowBox[{"a", "+", "b"}], ")"}], "2"], "-", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], "2"], 
    RowBox[{"4", "L"}]]}]}]], "Input",
 CellChangeTimes->{{3.5051514228605523`*^9, 3.5051514920025525`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ws", "[", 
   RowBox[{"L_", ",", "a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"L", "+", "a", "-", "b"}], ")"}], "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.505158170540552*^9, 3.5051582192255526`*^9}}],

Cell[TextData[{
 "For prices ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "i"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "j"], TraditionalForm]]],
 " consumer expected (price plus switching and transportation) costs in \
segment i",
 "\[Rule]j ",
 "are given by:"
}], "Text",
 CellChangeTimes->{{3.5051689102130003`*^9, 3.505169002442*^9}, {
  3.505175572885*^9, 3.505175575815*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pricestptswitch", "=", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Ww", "[", 
     RowBox[{"L", ",", 
      RowBox[{"pi", "+", 
       RowBox[{"dc", " ", 
        RowBox[{"Ww", "[", 
         RowBox[{"L", ",", "pi", ",", 
          RowBox[{"s", "+", "pj"}]}], "]"}]}]}], ",", 
      RowBox[{"pj", "+", 
       RowBox[{"dc", " ", 
        RowBox[{"Ww", "[", 
         RowBox[{"L", ",", 
          RowBox[{"s", "+", "pi"}], ",", "pj"}], "]"}]}]}]}], "]"}], "]"}], "/.",
    
   RowBox[{"L", "\[Rule]", "1"}]}]}]], "Input",
 CellChangeTimes->{{3.5051515053925524`*^9, 3.5051516140575523`*^9}, {
  3.5051868423147526`*^9, 3.5051868856347528`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "dc"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"pi", "-", "pj"}], ")"}], "2"], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"pi", "+", "pj"}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "dc", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"pi", "-", "pj"}], ")"}], "2"]}], ")"}], " ", "s"}], "-", 
    RowBox[{"dc", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"dc", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"pi", "-", "pj"}], ")"}], "2"]}]}], ")"}], " ", 
     SuperscriptBox["s", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.505186874660753*^9, 3.505194616034753*^9, 
  3.505195894521753*^9, 3.5051968060427527`*^9, 3.5070617386675997`*^9, 
  3.507306300023365*^9, 3.5073425565446*^9, 3.5074880781741514`*^9, 
  3.5075072718533607`*^9, 3.5081724937209997`*^9, 3.5083060759675646`*^9, 
  3.5484436686775827`*^9, 3.5484437508122807`*^9, 3.548444209174497*^9}]
}, Open  ]],

Cell["where we've normalized L=1", "Text",
 CellChangeTimes->{{3.5051689574110003`*^9, 3.505168960543*^9}, {
  3.505186916889753*^9, 3.5051869243617525`*^9}}],

Cell[TextData[{
 "Changing variables so that sum= ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "i"], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "j"], TraditionalForm]]],
 " and dif= ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "i"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "j"], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{
  3.505152866618552*^9, {3.505168991988*^9, 3.505169056718*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pricestptswitch", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"FullSimplify", "[", 
       RowBox[{"pricestptswitch", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"pi", "\[Rule]", 
           RowBox[{"sum", "-", "pj"}]}], ",", 
          RowBox[{"L", "\[Rule]", "1"}]}], "}"}]}], "]"}], "/.", 
      RowBox[{"pj", "\[Rule]", 
       RowBox[{
        RowBox[{"sum", "/", "2"}], "+", 
        RowBox[{"dif", "/", "2"}]}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"sum", ",", "dif"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5051534156475525`*^9, 3.505153425934552*^9}, {
  3.5051534931045523`*^9, 3.5051535148015523`*^9}, {3.5051535558435526`*^9, 
  3.5051535619735527`*^9}, {3.5051535935155525`*^9, 3.5051535965275526`*^9}, {
  3.505186902631753*^9, 3.5051869047137527`*^9}, {3.505186965672753*^9, 
  3.505186981315753*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "dc", "-", 
     RowBox[{"dc", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "s"}], ")"}], " ", "s"}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["dif", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     RowBox[{"dc", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"s", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", 
           RowBox[{"dc", " ", "s"}]}], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", 
     RowBox[{"2", " ", "dc"}]}], ")"}], " ", "sum"}]}]], "Output",
 CellChangeTimes->{
  3.5051534270565524`*^9, 3.5051535001855526`*^9, {3.5051535412795525`*^9, 
   3.5051535628215523`*^9}, 3.5051535968655524`*^9, 3.5051869833077526`*^9, 
   3.505194616072753*^9, 3.505195896046753*^9, 3.5051968060647526`*^9, 
   3.5070617413156*^9, 3.507306301308365*^9, 3.5073425578196*^9, 
   3.507488079442151*^9, 3.5075072732833605`*^9, 3.508172495144*^9, 
   3.5083060759955645`*^9, 3.5484436691176076`*^9, 3.5484437508612833`*^9, 
   3.5484442092174997`*^9}]
}, Open  ]],

Cell[TextData[{
 "Now we aggregate across segments. Notice that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"ij", "=", "1"}], 
       RowBox[{
        RowBox[{"N", "(", 
         RowBox[{"N", "-", "1"}], ")"}], "/", "2"}]], 
      SubscriptBox["p", "i"]}], "+", 
     SubscriptBox["p", "j"]}], "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "N"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"N", "-", "1"}], ")"}], 
      SubscriptBox["p", "i"]}]}]}], TraditionalForm]]],
 " then ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["2", 
       RowBox[{"N", "(", 
        RowBox[{"N", "-", "1"}], ")"}]], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"ij", "=", "1"}], 
        RowBox[{
         RowBox[{"N", "(", 
          RowBox[{"N", "-", "1"}], ")"}], "/", "2"}]], 
       SubscriptBox["p", "i"]}]}], "+", 
     SubscriptBox["p", "j"]}], "=", 
    RowBox[{"2", 
     OverscriptBox["p", "_"]}]}], TraditionalForm]]],
 "\nAnd: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FractionBox["2", 
      RowBox[{"N", "(", 
       RowBox[{"N", "-", "1"}], ")"}]], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"ij", "=", "1"}], 
       RowBox[{
        RowBox[{"N", "(", 
         RowBox[{"N", "-", "1"}], ")"}], "/", "2"}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["p", "i"], "-", 
         SubscriptBox["p", "j"]}], ")"}], "2"]}]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"2", "N"}], 
      RowBox[{"N", "-", "1"}]], 
     SubsuperscriptBox["\[Sigma]", "p", "2"]}]}], TraditionalForm]]],
 "\nThe average of the constant term remains constant."
}], "Text",
 CellChangeTimes->{{3.5051536844515524`*^9, 3.5051536888675528`*^9}, {
  3.5051537276015525`*^9, 3.505153806408552*^9}, {3.5051538373215523`*^9, 
  3.5051539068255525`*^9}, {3.505153949257552*^9, 3.5051539513785524`*^9}, {
  3.505154028908552*^9, 3.5051540462615523`*^9}, {3.5051545977745523`*^9, 
  3.505154627948552*^9}, {3.5051546794725523`*^9, 3.505154713184552*^9}, {
  3.505154855514552*^9, 3.505154864368552*^9}, {3.505169071698*^9, 
  3.505169090315*^9}, {3.5051691392060003`*^9, 3.505169150481*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pricestptswitch", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{"pricestptswitch", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sum", "\[Rule]", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Mu]", "p"]}]}], ",", " ", 
        RowBox[{"dif", "\[Rule]", 
         SqrtBox[
          RowBox[{
           FractionBox[
            RowBox[{"2", "N"}], 
            RowBox[{"N", "-", "1"}]], 
           SubsuperscriptBox["\[Sigma]", "p", "2"]}]]}]}], "}"}]}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["\[Mu]", "p"], ",", 
      SubsuperscriptBox["\[Sigma]", "p", "2"]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.505153960526552*^9, 3.505154004738552*^9}, {
   3.5051548787985525`*^9, 3.5051549872395525`*^9}, 3.5051575636975527`*^9, {
   3.5051691627980003`*^9, 3.5051691649560003`*^9}, {3.5051869919727526`*^9, 
   3.5051869932607527`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "dc", "-", 
     RowBox[{"dc", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "s"}], ")"}], " ", "s"}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "dc"}], ")"}], " ", 
   SubscriptBox["\[Mu]", "p"]}], "-", 
  FractionBox[
   RowBox[{"N", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"dc", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"s", " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", 
            RowBox[{"dc", " ", "s"}]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
    SubsuperscriptBox["\[Sigma]", "p", "2"]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "N"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.505154912658552*^9, 3.5051549578605523`*^9}, 
   3.5051549894845524`*^9, 3.5051575667825527`*^9, 3.505169166789*^9, 
   3.5051869977737527`*^9, 3.5051946161117525`*^9, 3.505195897487753*^9, 
   3.505196806084753*^9, 3.5070617429236*^9, 3.507306302613365*^9, 
   3.5073425590906*^9, 3.507488081125151*^9, 3.5075072747863607`*^9, 
   3.508172496501*^9, 3.5083060760245647`*^9, 3.5484436695716333`*^9, 
   3.548443750912286*^9, 3.5484442092625017`*^9}]
}, Open  ]],

Cell["\<\
Therefore consumer price+transportation+switching costs are decreasing in the \
variance of prices.  This aggregates the two lifetime periods.\
\>", "Text",
 CellChangeTimes->{{3.5051552666665525`*^9, 3.5051553291025524`*^9}, {
  3.505175585609*^9, 3.505175586888*^9}, {3.5051874981677527`*^9, 
  3.5051875182747526`*^9}}],

Cell[TextData[{
 "From HHIdynamic we can derive the shares in terms of costs:\n",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "i"], "\[Rule]", 
   RowBox[{
    FractionBox["1", "N"], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "N"}], ")"}], "2"], " ", 
      SubscriptBox["c", "i"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"s", " ", 
         SubscriptBox["\[Delta]", "c"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Zeta]", "1"]}], ")"}]}], 
     RowBox[{"N", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "N", "+", "\[Beta]", "+", 
        RowBox[{"s", " ", "\[Beta]", " ", 
         SubscriptBox["\[Delta]", "c"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "N", "+", 
        SubscriptBox["\[Zeta]", "1"]}], ")"}]}]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "N"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"s", " ", 
         SubscriptBox["\[Delta]", "c"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Zeta]", "1"]}], ")"}], " ", 
      SubscriptBox[
       OverscriptBox["c", "_"], 
       RowBox[{"-", "i"}]]}], 
     RowBox[{"N", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "N", "+", "\[Beta]", "+", 
        RowBox[{"s", " ", "\[Beta]", " ", 
         SubscriptBox["\[Delta]", "c"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "N", "+", 
        SubscriptBox["\[Zeta]", "1"]}], ")"}]}]]}]}]], "Output",
  CellChangeTimes->{3.505059141446*^9, 3.505059319704*^9, 3.505059607744*^9, 
   3.505063361895775*^9, 3.505065529598775*^9}]
}], "Text",
 CellChangeTimes->{{3.505152126613552*^9, 3.5051522172375526`*^9}, {
   3.5051524137415524`*^9, 3.5051524385645523`*^9}, 3.5051528500535526`*^9, {
   3.505171859666*^9, 3.5051718681800003`*^9}, {3.505175712409*^9, 
   3.5051757373529997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SharesSSc", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["x", "i"], "\[Rule]", 
        RowBox[{
         FractionBox["1", "N"], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "N"}], ")"}], "2"], " ", 
           SubscriptBox["c", "i"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"s", " ", "dc"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Zeta]", "1"]}], ")"}]}], 
          RowBox[{"N", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "N", "+", "\[Beta]", "+", 
             RowBox[{"s", " ", "\[Beta]", " ", "dc"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "N", "+", 
             SubscriptBox["\[Zeta]", "1"]}], ")"}]}]], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "N"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"s", " ", "dc"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Zeta]", "1"]}], ")"}], " ", 
           SubscriptBox[
            OverscriptBox["c", "_"], 
            RowBox[{"-", "i"}]]}], 
          RowBox[{"N", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "N", "+", "\[Beta]", "+", 
             RowBox[{"s", " ", "\[Beta]", " ", "dc"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "N", "+", 
             SubscriptBox["\[Zeta]", "1"]}], ")"}]}]]}]}], "/.", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["c", "_"], 
         RowBox[{"-", "i"}]], "\[Rule]", 
        RowBox[{
         RowBox[{
          FractionBox["N", 
           RowBox[{"N", "-", "1"}]], 
          OverscriptBox["c", "_"]}], "-", 
         FractionBox[
          SubscriptBox["c", "i"], 
          RowBox[{"N", "-", "1"}]]}]}]}], "}"}], "]"}], ",", 
    RowBox[{"{", " ", 
     RowBox[{
      OverscriptBox["c", "_"], " ", ",", " ", 
      SubscriptBox["c", "i"]}], " ", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.505171870947*^9, 3.5051719143059998`*^9}, {
  3.5051870519137526`*^9, 3.5051870818077526`*^9}, {3.5051945960237527`*^9, 
  3.5051946038807526`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["x", "i"], "\[Rule]", 
   RowBox[{
    FractionBox["1", "N"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "N"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"dc", " ", "s"}]}], ")"}], " ", 
      OverscriptBox["c", "_"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Zeta]", "1"]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "N", "+", "\[Beta]", "+", 
        RowBox[{"dc", " ", "s", " ", "\[Beta]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "N", "+", 
        SubscriptBox["\[Zeta]", "1"]}], ")"}]}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "N"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"dc", " ", "s"}]}], ")"}], " ", 
      SubscriptBox["c", "i"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Zeta]", "1"]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "N", "+", "\[Beta]", "+", 
        RowBox[{"dc", " ", "s", " ", "\[Beta]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "N", "+", 
        SubscriptBox["\[Zeta]", "1"]}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5051719205179996`*^9, 3.5051870837137527`*^9, {3.5051946115527525`*^9, 
   3.5051946161487527`*^9}, 3.5051958983197527`*^9, 3.505196806106753*^9, 
   3.5070617461616*^9, 3.507306303422365*^9, 3.5073425598076*^9, 
   3.5074880819621515`*^9, 3.5075072755973606`*^9, 3.508172497299*^9, 
   3.5083060760515647`*^9, 3.548443669892652*^9, 3.5484437509552884`*^9, 
   3.5484442093005047`*^9}]
}, Open  ]],

Cell["In terms of prices", "Text",
 CellChangeTimes->{{3.505175823709*^9, 3.505175839587*^9}}],

Cell["From HHI dynamic we have:", "Text",
 CellChangeTimes->{{3.505170272135*^9, 3.5051702795810003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"alpha1", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Alpha]", "i"], "\[Rule]", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Zeta]", "0"]}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "N", "+", 
            SubscriptBox["\[Zeta]", "1"]}], ")"}]}], "-", 
         RowBox[{
          SubscriptBox["c", "i"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Zeta]", "1"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "N", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "N"}], ")"}], " ", 
             SubscriptBox["\[Zeta]", "1"]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "N"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Zeta]", "1"]}], ")"}], " ", 
          SubscriptBox["\[Zeta]", "1"], " ", 
          SubscriptBox[
           OverscriptBox["c", "_"], 
           RowBox[{"-", "i"}]]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SubscriptBox["\[Zeta]", "1"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "N", "+", 
           SubscriptBox["\[Zeta]", "1"]}], ")"}]}]]}], "/.", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["c", "_"], 
        RowBox[{"-", "i"}]], "\[Rule]", 
       RowBox[{
        RowBox[{
         FractionBox["N", 
          RowBox[{"N", "-", "1"}]], 
         OverscriptBox["c", "_"]}], "-", 
        FractionBox[
         SubscriptBox["c", "i"], 
         RowBox[{"N", "-", "1"}]]}]}]}], "}"}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.505170284771*^9, 3.505170317084*^9}, {3.505171739525*^9,
    3.505171740005*^9}, {3.5051717702139997`*^9, 3.5051718158310003`*^9}, 
   3.505187205077753*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Alpha]", "i"], "\[Rule]", 
   RowBox[{
    SubscriptBox["c", "i"], "-", 
    FractionBox[
     SubscriptBox["\[Zeta]", "0"], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubscriptBox["\[Zeta]", "1"]}]], "+", 
    FractionBox[
     RowBox[{"N", " ", 
      RowBox[{"(", 
       RowBox[{
        OverscriptBox["c", "_"], "-", 
        SubscriptBox["c", "i"]}], ")"}], " ", 
      SubscriptBox["\[Zeta]", "1"]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "N", "+", 
      SubscriptBox["\[Zeta]", "1"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.505187210645753*^9, 3.505194616169753*^9, 
  3.505195899139753*^9, 3.505196806131753*^9, 3.5070617513136*^9, 
  3.507306304231365*^9, 3.5073425605916*^9, 3.5074880829261513`*^9, 
  3.5075072764273605`*^9, 3.508172498072*^9, 3.5083060760785646`*^9, 
  3.5484436701806684`*^9, 3.548443750993291*^9, 3.5484442093405066`*^9}]
}, Open  ]],

Cell[TextData[{
 "We know that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["p", "i"], "="}], TraditionalForm]]],
 Cell[BoxData[
  SubscriptBox["\[Alpha]", "i"]],
  CellChangeTimes->{3.5051718174700003`*^9}],
 "+\[Beta] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "i"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["p", "_"], "=", 
    RowBox[{
     OverscriptBox["\[Alpha]", "_"], "+"}]}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   FractionBox["\[Beta]", "N"], TraditionalForm]]],
 "then ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["p", "i"], "-", 
      OverscriptBox["p", "_"]}], "=", 
     RowBox[{
      SubscriptBox["\[Alpha]", "i"], "-", 
      OverscriptBox["\[Alpha]", "_"], "+", 
      RowBox[{"\[Beta]", " ", 
       FormBox[
        RowBox[{"(", 
         SubscriptBox["x", "i"]}],
        TraditionalForm]}], "-", 
      RowBox[{"1", "/", "N"}]}]}], ")"}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.5051721489049997`*^9, 3.505172325473*^9}, {
  3.505187143622753*^9, 3.505187146480753*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pipbar", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Alpha]", "i"], "-", 
         OverscriptBox["\[Alpha]", "_"], "+", 
         RowBox[{"\[Beta]", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["x", "i"], "-", 
            RowBox[{"1", "/", "N"}]}], ")"}]}]}], "/.", "alpha1"}], "]"}], "/.",
       
      RowBox[{
       OverscriptBox["\[Alpha]", "_"], "->", 
       RowBox[{
        OverscriptBox["c", "_"], "-", 
        FractionBox[
         SubscriptBox["\[Zeta]", "0"], 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Zeta]", "1"]}]]}]}]}], "]"}], "/.", "SharesSSc"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.505172347226*^9, 3.505172438059*^9}, {3.505172512969*^9,
    3.505172588373*^9}, {3.505175789433*^9, 3.505175802538*^9}, 
   3.5051872746357527`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "N"}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     OverscriptBox["c", "_"], "-", 
     SubscriptBox["c", "i"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SubscriptBox["\[Zeta]", "1"]}], ")"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "N", "+", "\[Beta]", "+", 
     RowBox[{"dc", " ", "s", " ", "\[Beta]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "N", "+", 
     SubscriptBox["\[Zeta]", "1"]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.505172591606*^9, 3.5051758055889997`*^9, {3.5051872643717527`*^9, 
   3.505187276356753*^9}, 3.5051946162537527`*^9, 3.505195899379753*^9, 
   3.5051968061547527`*^9, 3.5070617517536*^9, 3.5073063044253654`*^9, 
   3.5073425607756*^9, 3.507488083124151*^9, 3.5075072766443605`*^9, 
   3.5081724982939997`*^9, 3.5083060761085644`*^9, 3.548443670264673*^9, 
   3.548443751033293*^9, 3.5484442093835087`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solcdif", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"pipbar", "/.", 
        RowBox[{
         SubscriptBox["c", "i"], "->", 
         RowBox[{
          OverscriptBox["c", "_"], "+", "cdif"}]}]}], "]"}], "\[Equal]", 
      "pdif"}], ",", "cdif"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.505176025316*^9, 3.505176086617*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"cdif", "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"pdif", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "N", "+", "\[Beta]", "+", 
        RowBox[{"dc", " ", "s", " ", "\[Beta]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "N", "+", 
        SubscriptBox["\[Zeta]", "1"]}], ")"}]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "N"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Zeta]", "1"]}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.505176038026*^9, 3.5051760872720003`*^9}, 
   3.505187299249753*^9, 3.505194616280753*^9, 3.505195899436753*^9, 
   3.5051968061807528`*^9, 3.5070617517746*^9, 3.507306304542365*^9, 
   3.5073425608156*^9, 3.5074880832071514`*^9, 3.5075072768143606`*^9, 
   3.5081724983859997`*^9, 3.5083060761315646`*^9, 3.548443670297675*^9, 
   3.5484437510712953`*^9, 3.5484442094255114`*^9}]
}, Open  ]],

Cell["The shares in terms of prices are given by:", "Text",
 CellChangeTimes->{{3.505187602408753*^9, 3.505187613275753*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SharesSSp", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"FullSimplify", "[", 
         RowBox[{"SharesSSc", "/.", 
          RowBox[{
           SubscriptBox["c", "i"], "->", 
           RowBox[{
            OverscriptBox["c", "_"], "+", "cdif"}]}]}], "]"}], ",", "cdif"}], 
       "]"}], "/.", "solcdif"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"N", ">", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.505175769237*^9, 3.5051757733929996`*^9}, {
   3.505175854323*^9, 3.5051759903199997`*^9}, 3.5051760232939997`*^9, {
   3.5051760966809998`*^9, 3.505176178241*^9}, {3.505187314778753*^9, 
   3.505187319440753*^9}, {3.5051873506377525`*^9, 3.5051873586967525`*^9}, 
   3.5051876443097525`*^9, {3.505187686954753*^9, 3.505187750511753*^9}, {
   3.505187800923753*^9, 3.5051878200457525`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["x", "i"], "\[Rule]", 
   FractionBox[
    RowBox[{"1", "-", "N", "+", 
     RowBox[{"N", " ", "pdif"}], "+", 
     RowBox[{"dc", " ", "N", " ", "pdif", " ", "s"}]}], 
    RowBox[{"N", "-", 
     SuperscriptBox["N", "2"]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.505176139811*^9, {3.505176171566*^9, 3.5051761788719997`*^9}, 
   3.505187360060753*^9, 3.5051876488737526`*^9, {3.505187690231753*^9, 
   3.505187750751753*^9}, {3.505187806390753*^9, 3.5051878214307528`*^9}, 
   3.5051946171047525`*^9, 3.5051959002997527`*^9, 3.505196806202753*^9, 
   3.5070617533946*^9, 3.5073063054043655`*^9, 3.5073425616736*^9, 
   3.507488084204151*^9, 3.5075072778233604`*^9, 3.508172499335*^9, 
   3.5083060761565647`*^9, 3.5484436706026926`*^9, 3.5484437511092973`*^9, 
   3.548444209474514*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["x", "i"], "-", 
    FractionBox["1", "N"], "+", 
    FractionBox[
     RowBox[{"pdif", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", " ", 
        RowBox[{"s", " ", "dc"}]}], ")"}]}], 
     RowBox[{"N", "-", "1"}]]}], "/.", "SharesSSp"}], "]"}]], "Input",
 CellChangeTimes->{{3.5051878285647526`*^9, 3.5051878692087526`*^9}, {
  3.505194915815753*^9, 3.5051949158357525`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.505187850640753*^9, 3.5051878695057526`*^9}, 
   3.5051946172037525`*^9, 3.505194916797753*^9, 3.5051959003807526`*^9, 
   3.5051968062227526`*^9, 3.5070617538616*^9, 3.507306305442365*^9, 
   3.5073425617076*^9, 3.507488084249151*^9, 3.5075072778743606`*^9, 
   3.508172499407*^9, 3.5083060761785645`*^9, 3.5484436706906977`*^9, 
   3.5484437511512995`*^9, 3.5484442095095162`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Costs", "Section",
 CellChangeTimes->{{3.505187901584753*^9, 3.5051879338097525`*^9}, {
   3.505187982633753*^9, 3.505187990428753*^9}, 3.505192712008753*^9, 
   3.505192784518753*^9, {3.5052338741027527`*^9, 3.505233883539753*^9}, {
   3.548435220827393*^9, 3.548435239706473*^9}}],

Cell[CellGroupData[{

Cell["Young Consumers", "Subsection",
 CellChangeTimes->{{3.5073076038403654`*^9, 3.5073076063153653`*^9}}],

Cell[CellGroupData[{

Cell["Transport costs", "Subsubsection",
 CellChangeTimes->{{3.507307620797365*^9, 3.5073076249543653`*^9}}],

Cell[TextData[{
 "Young consumers will pay the transport cost from their location to the firm \
they buy from. If equilibrium demand in segment i-j is equal x then average \
transport costs are ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["x", "2"], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}], "2"], "/", "2"}]}], 
   TraditionalForm]]],
 ". Steady state demand from young consumers in segment  i-j is (see equation \
11):"
}], "Text",
 CellChangeTimes->{{3.505188008565753*^9, 3.505188043353753*^9}, {
  3.5484352691771584`*^9, 3.5484352944886065`*^9}, {3.548435479906212*^9, 
  3.5484355152492332`*^9}, {3.548435622158348*^9, 3.5484356247974987`*^9}}],

Cell[BoxData[
 RowBox[{"dY", ":=", 
  FractionBox[
   RowBox[{"1", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"s", " ", "dc"}]}], ")"}], 
     RowBox[{"(", "pdif", ")"}]}]}], "2"]}]], "Input",
 CellChangeTimes->{{3.5051896602107525`*^9, 3.505189690980753*^9}, {
   3.5051898365427527`*^9, 3.505189889829753*^9}, {3.5051902131617527`*^9, 
   3.5051902179577527`*^9}, 3.505191481704753*^9, {3.5051915351427526`*^9, 
   3.505191535334753*^9}, 3.5484356188641596`*^9}],

Cell[TextData[{
 "where dY is the demand in segment i-j and pdif is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["p", "j"], "-", 
    SubscriptBox["p", "i"]}], TraditionalForm]]],
 ". Transport costs in segment i-j, as a function of pdif, add up to to"
}], "Text",
 CellChangeTimes->{{3.5484355440318794`*^9, 3.54843568391588*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tpty", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["dY", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "dY"}], ")"}], "2"]}], ")"}], "/", "2"}], "]"}], 
    ",", "pdif"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.507306332728365*^9, {3.5073083566373653`*^9, 3.507308359254365*^9}, 
   3.548439120842461*^9, {3.548439290484164*^9, 3.5484392987876387`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["pdif", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"2", " ", "dc", " ", "s"}], "+", 
     RowBox[{
      SuperscriptBox["dc", "2"], " ", 
      SuperscriptBox["s", "2"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.5073063330193653`*^9, 3.507306597195365*^9, 
  3.507308359869365*^9, 3.5073425618046*^9, 3.507488084341151*^9, 
  3.5075072779743605`*^9, 3.508172499505*^9, 3.5083060762265644`*^9, 
  3.5484356986597233`*^9, 3.548439122943581*^9, 3.5484392993766727`*^9, 
  3.5484436707417*^9, 3.5484437511823015`*^9, 3.548444209540518*^9}]
}, Open  ]],

Cell[TextData[{
 "Taking the average over segments (and noting that ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Sigma]", "p", "2"], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"J", "-", "1"}], ")"}], 
      RowBox[{"-", "1"}]], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"i", "=", "1"}], "J"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["p", "i"], "-", 
         OverscriptBox["p", "_"]}], ")"}], "2"]}]}], "="}]}]],
  CellChangeTimes->{{3.5051899158757524`*^9, 3.505189943712753*^9}, 
    3.505190192620753*^9, {3.5051902411417527`*^9, 3.5051902740037527`*^9}, {
    3.505190319289753*^9, 3.505190353188753*^9}, {3.5051904002537527`*^9, 
    3.505190439962753*^9}, {3.5051904800127525`*^9, 3.505190485020753*^9}, {
    3.505190530581753*^9, 3.505190554566753*^9}, {3.5051914885557528`*^9, 
    3.5051914906017528`*^9}, {3.505191540294753*^9, 3.5051915426947527`*^9}, {
    3.505196675535753*^9, 3.5051966799017525`*^9}, {3.507308367884365*^9, 
    3.5073083699013653`*^9}}],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", "1"}], ")"}], "2", "J"}], ")"}], 
    RowBox[{"-", "1"}]], 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "1"}], "J"], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"j", "\[NotEqual]", "i"}], "J"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["p", "i"], "-", 
        SubscriptBox["p", "j"]}], ")"}], "2"]}]}]}]],
  CellChangeTimes->{{3.5051899158757524`*^9, 3.505189943712753*^9}, 
    3.505190192620753*^9, {3.5051902411417527`*^9, 3.5051902740037527`*^9}, {
    3.505190319289753*^9, 3.505190353188753*^9}, {3.5051904002537527`*^9, 
    3.505190439962753*^9}, {3.5051904800127525`*^9, 3.505190485020753*^9}, {
    3.505190530581753*^9, 3.505190554566753*^9}, {3.5051914885557528`*^9, 
    3.5051914906017528`*^9}, {3.505191540294753*^9, 3.5051915426947527`*^9}, {
    3.505196675535753*^9, 3.5051966799017525`*^9}, {3.507308367884365*^9, 
    3.5073083699013653`*^9}}],
 ", and Average_Transport_Costs=",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", "1"}], ")"}], "J"}], ")"}], 
    RowBox[{"-", "1"}]], 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "1"}], "J"], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"j", "\[NotEqual]", "i"}], "J"], 
     RowBox[{"AvgTptCost", 
      RowBox[{"(", 
       RowBox[{"i", ",", "j"}], ")"}]}]}]}]}]],
  CellChangeTimes->{{3.5051899158757524`*^9, 3.505189943712753*^9}, 
    3.505190192620753*^9, {3.5051902411417527`*^9, 3.5051902740037527`*^9}, {
    3.505190319289753*^9, 3.505190353188753*^9}, {3.5051904002537527`*^9, 
    3.505190439962753*^9}, {3.5051904800127525`*^9, 3.505190485020753*^9}, {
    3.505190530581753*^9, 3.505190554566753*^9}, {3.5051914885557528`*^9, 
    3.5051914906017528`*^9}, {3.505191540294753*^9, 3.5051915426947527`*^9}, {
    3.505196675535753*^9, 3.5051966799017525`*^9}, {3.507308367884365*^9, 
    3.5073083699013653`*^9}}],
 ") average transport costs are:"
}], "Text",
 CellChangeTimes->{{3.5073066541213655`*^9, 3.507306685997365*^9}, {
   3.5484357200259457`*^9, 3.5484358755758424`*^9}, {3.548436948194193*^9, 
   3.5484369491852493`*^9}, 3.548437134587854*^9, {3.548437836341992*^9, 
   3.548437874819193*^9}, {3.5484388309468803`*^9, 3.5484389205770063`*^9}, {
   3.548439002335683*^9, 3.5484391174552674`*^9}, {3.5484392115486493`*^9, 
   3.5484392552511487`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TptCostY", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"FullSimplify", "[", "tpty", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"pdif", ",", 
          SuperscriptBox["pdif", "2"]}], "}"}]}], "]"}], "/.", 
      RowBox[{"pdif", "\[Rule]", 
       SqrtBox[
        RowBox[{"2", 
         SubsuperscriptBox["\[Sigma]", "p", "2"]}]]}]}], "]"}], ",", 
    SubsuperscriptBox["\[Sigma]", "p", "2"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5051899158757524`*^9, 3.505189943712753*^9}, 
   3.505190192620753*^9, {3.5051902411417527`*^9, 3.5051902740037527`*^9}, {
   3.505190319289753*^9, 3.505190353188753*^9}, {3.5051904002537527`*^9, 
   3.505190439962753*^9}, {3.5051904800127525`*^9, 3.505190485020753*^9}, {
   3.505190530581753*^9, 3.505190554566753*^9}, {3.5051914885557528`*^9, 
   3.5051914906017528`*^9}, {3.505191540294753*^9, 3.5051915426947527`*^9}, {
   3.505196675535753*^9, 3.5051966799017525`*^9}, {3.507308367884365*^9, 
   3.5073083699013653`*^9}, 3.5484437304171133`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"dc", " ", "s"}]}], ")"}], "2"], " ", 
   SubsuperscriptBox["\[Sigma]", "p", "2"]}]}]], "Output",
 CellChangeTimes->{3.507307568122365*^9, 3.5073083708353653`*^9, 
  3.5073425618366003`*^9, 3.507488084368151*^9, 3.5075072780113606`*^9, 
  3.508172499534*^9, 3.5083060762485647`*^9, 3.548443670769702*^9, 
  3.5484437512293043`*^9, 3.5484442095805206`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Prices Paid", "Subsubsection",
 CellChangeTimes->{{3.5073076418193655`*^9, 3.507307643962365*^9}}],

Cell["The average price paid in segment i-j is:", "Text",
 CellChangeTimes->{{3.507307777853365*^9, 3.507307786641365*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pricey", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"dY", " ", "pi"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "dY"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"pdif", "+", "pi"}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.507307793966365*^9, 3.5073078168093653`*^9}, {
  3.507307852820365*^9, 3.5073078694403653`*^9}, {3.5073083751873655`*^9, 
  3.507308379844365*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{"pdif", "+", 
    RowBox[{"2", " ", "pi"}], "-", 
    RowBox[{
     SuperscriptBox["pdif", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"dc", " ", "s"}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.5073078629413652`*^9, 3.507307869798365*^9}, 
   3.507308380318365*^9, 3.5073425619105997`*^9, 3.5074880844381514`*^9, 
   3.5075072780893607`*^9, 3.5081724996029997`*^9, 3.5083060763105645`*^9, 
   3.5484394182204704`*^9, 3.548443670826705*^9, 3.548443751281307*^9, 
   3.548444209619522*^9}]
}, Open  ]],

Cell[TextData[{
 "Taking the average over segments, (and noting that ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox["p", "_"], "=", 
   RowBox[{
    SuperscriptBox["J", 
     RowBox[{"-", "1"}]], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "J"], 
     SubscriptBox["p", "i"]}]}]}]],
  CellChangeTimes->{{3.5051899158757524`*^9, 3.505189943712753*^9}, 
    3.505190192620753*^9, {3.5051902411417527`*^9, 3.5051902740037527`*^9}, {
    3.505190319289753*^9, 3.505190353188753*^9}, {3.5051904002537527`*^9, 
    3.505190439962753*^9}, {3.5051904800127525`*^9, 3.505190485020753*^9}, {
    3.505190530581753*^9, 3.505190554566753*^9}, {3.5051914885557528`*^9, 
    3.5051914906017528`*^9}, {3.505191540294753*^9, 3.5051915426947527`*^9}, {
    3.505196675535753*^9, 3.5051966799017525`*^9}, {3.507308367884365*^9, 
    3.5073083699013653`*^9}}],
 ", and therefore,",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"J", "-", "1"}], ")"}], "J"}], ")"}], 
       RowBox[{"-", "1"}]], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "1"}], "J"], 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"j", "\[NotEqual]", "i"}], "J"], 
        RowBox[{"pdif", 
         RowBox[{"(", 
          RowBox[{"j", ",", "i"}], ")"}], "2"}]}]}]}], "+", 
     SubscriptBox["p", "i"]}], "=", "2"}]}]],
  CellChangeTimes->{{3.5051899158757524`*^9, 3.505189943712753*^9}, 
    3.505190192620753*^9, {3.5051902411417527`*^9, 3.5051902740037527`*^9}, {
    3.505190319289753*^9, 3.505190353188753*^9}, {3.5051904002537527`*^9, 
    3.505190439962753*^9}, {3.5051904800127525`*^9, 3.505190485020753*^9}, {
    3.505190530581753*^9, 3.505190554566753*^9}, {3.5051914885557528`*^9, 
    3.5051914906017528`*^9}, {3.505191540294753*^9, 3.5051915426947527`*^9}, {
    3.505196675535753*^9, 3.5051966799017525`*^9}, {3.507308367884365*^9, 
    3.5073083699013653`*^9}}],
 Cell[BoxData[
  OverscriptBox["p", "_"]],
  CellChangeTimes->{{3.5051899158757524`*^9, 3.505189943712753*^9}, 
    3.505190192620753*^9, {3.5051902411417527`*^9, 3.5051902740037527`*^9}, {
    3.505190319289753*^9, 3.505190353188753*^9}, {3.5051904002537527`*^9, 
    3.505190439962753*^9}, {3.5051904800127525`*^9, 3.505190485020753*^9}, {
    3.505190530581753*^9, 3.505190554566753*^9}, {3.5051914885557528`*^9, 
    3.5051914906017528`*^9}, {3.505191540294753*^9, 3.5051915426947527`*^9}, {
    3.505196675535753*^9, 3.5051966799017525`*^9}, {3.507308367884365*^9, 
    3.5073083699013653`*^9}}],
 ")  the average price paid by young consumers is:"
}], "Text",
 CellChangeTimes->{{3.548439422654724*^9, 3.548439475595752*^9}, {
  3.5484395497219915`*^9, 3.54843961403067*^9}, {3.548439693974242*^9, 
  3.548439794513993*^9}, {3.548439856601544*^9, 3.5484399108996496`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PriceY", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"FullSimplify", "[", "pricey", "]"}], "/.", 
        RowBox[{"pi", "\[Rule]", 
         RowBox[{
          OverscriptBox["p", "_"], "-", 
          RowBox[{"pdif", "/", "2"}]}]}]}], ")"}], "/.", 
      RowBox[{"pdif", "\[Rule]", 
       SqrtBox[
        RowBox[{"2", 
         SubsuperscriptBox["\[Sigma]", "p", "2"]}]]}]}], "]"}], ",", 
    SubsuperscriptBox["\[Sigma]", "p", "2"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5073083908213654`*^9, 3.507308395773365*^9}, {
  3.507308426667365*^9, 3.507308520639365*^9}, {3.5073085736943655`*^9, 
  3.507308618839365*^9}}],

Cell[BoxData[
 RowBox[{
  OverscriptBox["p", "_"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     RowBox[{"dc", " ", "s"}]}], ")"}], " ", 
   SubsuperscriptBox["\[Sigma]", "p", "2"]}]}]], "Output",
 CellChangeTimes->{3.507308620653365*^9, 3.5073425619566*^9, 
  3.5074880844621515`*^9, 3.5075072781423607`*^9, 3.5081724996289997`*^9, 
  3.5083060763945646`*^9, 3.548443670864708*^9, 3.5484437513133087`*^9, 
  3.5484442096705256`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Old Consumers", "Subsection",
 CellChangeTimes->{{3.5073090013453655`*^9, 3.5073090046683655`*^9}}],

Cell["\<\
The marginal consumer for those who bought from firm i and firm j, \
respectively, are located at:\
\>", "Text",
 CellChangeTimes->{{3.507309046657365*^9, 3.507309088126365*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dOi", "=", 
  FractionBox[
   RowBox[{"1", "+", "pdif", "+", "s"}], "2"]}], "\[IndentingNewLine]", 
 RowBox[{"dOj", "=", 
  FractionBox[
   RowBox[{"1", "+", "pdif", "-", "s"}], "2"]}]}], "Input",
 CellChangeTimes->{{3.5051915005057526`*^9, 3.5051916119117527`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", "pdif", "+", "s"}], ")"}]}]], "Output",
 CellChangeTimes->{3.505191612706753*^9, 3.5051946172507524`*^9, 
  3.5051959004307528`*^9, 3.505196806272753*^9, 3.5070617539166*^9, 
  3.5073063054863653`*^9, 3.5073425619986*^9, 3.507488084484151*^9, 
  3.5075072781793604`*^9, 3.5081724996549997`*^9, 3.5083060764155645`*^9, 
  3.5484402879422154`*^9, 3.548443670940712*^9, 3.548443751404314*^9, 
  3.548444209733529*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", "pdif", "-", "s"}], ")"}]}]], "Output",
 CellChangeTimes->{3.505191612706753*^9, 3.5051946172507524`*^9, 
  3.5051959004307528`*^9, 3.505196806272753*^9, 3.5070617539166*^9, 
  3.5073063054863653`*^9, 3.5073425619986*^9, 3.507488084484151*^9, 
  3.5075072781793604`*^9, 3.5081724996549997`*^9, 3.5083060764155645`*^9, 
  3.5484402879422154`*^9, 3.548443670940712*^9, 3.548443751404314*^9, 
  3.548444209773531*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transport costs", "Subsubsection",
 CellChangeTimes->{{3.5073108369143653`*^9, 3.507310839593365*^9}}],

Cell["\<\
Transport costs borne by old consumers in the segment i-j are:\
\>", "Text",
 CellChangeTimes->{{3.505191927164753*^9, 3.505191939551753*^9}, {
   3.507309578803365*^9, 3.507309589933365*^9}, 3.508173207545*^9, {
   3.5484399634516554`*^9, 3.5484400096102953`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tpto", "=", 
  RowBox[{"FullSimplify", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"dY", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["dOi", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "dOi"}], ")"}], "2"]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "dY"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["dOj", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "dOj"}], ")"}], "2"]}], ")"}]}]}], "2"], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5073096049203653`*^9, 3.507309614975365*^9}, 
   3.548440046763421*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    SuperscriptBox["s", "2"], "+", 
    RowBox[{
     SuperscriptBox["pdif", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", "s", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"dc", " ", "s"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]], "Output",\

 CellChangeTimes->{3.5073096157953653`*^9, 3.5073425621745996`*^9, 
  3.5074880846201515`*^9, 3.5075072783563604`*^9, 3.508172499792*^9, 
  3.5083060765185647`*^9, 3.5484402941265693`*^9, 3.548443671116722*^9, 
  3.548443751524321*^9, 3.5484442098445354`*^9}]
}, Open  ]],

Cell["Taking averages over segments:", "Text",
 CellChangeTimes->{{3.5484400604732046`*^9, 3.548440065960519*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TptCostO", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{"tpto", "/.", 
      RowBox[{"pdif", "\[Rule]", 
       SqrtBox[
        RowBox[{"2", 
         SubsuperscriptBox["\[Sigma]", "p", "2"]}]]}]}], "]"}], ",", 
    SubsuperscriptBox["\[Sigma]", "p", "2"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5073096417433653`*^9, 3.5073096457623653`*^9}, 
   3.548440049835596*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["s", "2"]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", 
     RowBox[{"4", " ", "s", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"dc", " ", "s"}]}], ")"}]}]}], ")"}], " ", 
   SubsuperscriptBox["\[Sigma]", "p", "2"]}]}]], "Output",
 CellChangeTimes->{3.5073096466163654`*^9, 3.5073425623146*^9, 
  3.507488084776151*^9, 3.507507278508361*^9, 3.508172499926*^9, 
  3.508306076543565*^9, 3.548440294249576*^9, 3.548443671234729*^9, 
  3.548443751600325*^9, 3.5484442099125395`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["switching costs", "Subsubsection",
 CellChangeTimes->{{3.5073108369143653`*^9, 3.507310852384365*^9}}],

Cell["Switching costs in the segment i-j are given by:", "Text",
 CellChangeTimes->{{3.505190608494753*^9, 3.5051906250297527`*^9}, {
  3.505191695908753*^9, 3.505191698224753*^9}, {3.5484400831124997`*^9, 
  3.5484400943431425`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"swto", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"dY", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "dOi"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "dY"}], ")"}], "dOj"}]}], ")"}], " ", "s"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.507310584886365*^9, 3.5073105887103653`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", "s", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "s", "+", 
    RowBox[{
     SuperscriptBox["pdif", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"dc", " ", "s"}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.507310590272365*^9, 3.5073425623506002`*^9, 
  3.5074880848011513`*^9, 3.5075072785493603`*^9, 3.50817249995*^9, 
  3.5083060765655646`*^9, 3.5484403001839156`*^9, 3.548443671294732*^9, 
  3.5484437516733294`*^9, 3.548444209977543*^9}]
}, Open  ]],

Cell["Taking averages over segments:", "Text",
 CellChangeTimes->{{3.5484400604732046`*^9, 3.548440065960519*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SwtCostO", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{"swto", "/.", 
      RowBox[{"pdif", "\[Rule]", 
       SqrtBox[
        RowBox[{"2", 
         SubsuperscriptBox["\[Sigma]", "p", "2"]}]]}]}], "]"}], ",", 
    SubsuperscriptBox["\[Sigma]", "p", "2"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.505191631191753*^9, 3.505191764346753*^9}, {
   3.505192301021753*^9, 3.505192311297753*^9}, 3.505196687730753*^9, 
   3.507310596971365*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "s"}], ")"}], " ", "s"}], "-", 
  RowBox[{"s", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"dc", " ", "s"}]}], ")"}], " ", 
   SubsuperscriptBox["\[Sigma]", "p", "2"]}]}]], "Output",
 CellChangeTimes->{
  3.5051917093327527`*^9, {3.505191746702753*^9, 3.5051917648027525`*^9}, 
   3.5051923121567526`*^9, 3.5051946173357525`*^9, 3.5051959008127527`*^9, 
   3.5051968063787527`*^9, 3.5070617542335997`*^9, 3.507306305636365*^9, 
   3.5073105984543653`*^9, 3.5073425624365997`*^9, 3.5074880848771515`*^9, 
   3.5075072786313605`*^9, 3.508172500021*^9, 3.5083060765905647`*^9, 
   3.548440300308923*^9, 3.5484436713857374`*^9, 3.5484437517473335`*^9, 
   3.5484442100435467`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Price paid", "Subsubsection",
 CellChangeTimes->{{3.5073108624963655`*^9, 3.507310879824365*^9}}],

Cell["Average price paid by old consumers attached to good i:", "Text",
 CellChangeTimes->{{3.507311058464365*^9, 3.507311069490365*^9}, {
  3.548440151861432*^9, 3.548440152197451*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pricepaidbyoldi", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"dOi", " ", "pi"}], " ", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "dOi"}], ")"}], "pj"}]}], "/.", 
    RowBox[{"pdif", "\[Rule]", 
     RowBox[{"pj", "-", "pi"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5073112256113653`*^9, 3.5073112735243654`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["pi", "2"]}], "-", 
    RowBox[{"pj", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "pj", "+", "s"}], ")"}]}], "+", 
    RowBox[{"pi", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", "pj"}], "+", "s"}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.5073112497863655`*^9, 3.507311273907365*^9}, 
   3.5073425624896*^9, 3.507488084921151*^9, 3.507507278666361*^9, 
   3.508172500054*^9, 3.5083060766175647`*^9, 3.548440308461389*^9, 
   3.5484436714597416`*^9, 3.548443751874341*^9, 3.54844421010655*^9}]
}, Open  ]],

Cell["Average price paid by old consumers attached to good j:", "Text",
 CellChangeTimes->{3.548440181829146*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pricepaidbyoldj", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"dOj", " ", "pi"}], " ", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "dOj"}], ")"}], "pj"}]}], "/.", 
    RowBox[{"pdif", "\[Rule]", 
     RowBox[{"pj", "-", "pi"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.507314830428365*^9, 3.507314838890365*^9}, 
   3.507315376742365*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["pi", "2"]}], "+", 
    RowBox[{"pi", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", "pj"}], "-", "s"}], ")"}]}], "+", 
    RowBox[{"pj", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "pj", "+", "s"}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.507315391647365*^9, 3.5073425625376*^9, 
  3.507488084980151*^9, 3.5075072787123604`*^9, 3.50817250009*^9, 
  3.5083060766445646`*^9, 3.5484403114225583`*^9, 3.548443671536746*^9, 
  3.548443751959346*^9, 3.5484442102295575`*^9}]
}, Open  ]],

Cell["Average price paid by consumers in segment i-j:", "Text",
 CellChangeTimes->{{3.507315399841365*^9, 3.507315417044365*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"aux1", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"pdif", "==", 
       RowBox[{"pj", "-", "pi"}]}], ",", 
      RowBox[{"psum", "\[Equal]", 
       RowBox[{"pj", "+", "pi"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"pi", ",", "pj"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"priceo", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"pricepaidbyoldi", " ", "dY"}], "+", 
      RowBox[{"pricepaidbyoldj", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "dY"}], ")"}]}]}], "/.", "aux1"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.507315605363365*^9, 3.5073156537743654`*^9}, {
  3.5484402058205185`*^9, 3.5484402060865335`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"pi", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "pdif"}], "+", "psum"}], ")"}]}]}], ",", 
    RowBox[{"pj", "\[Rule]", 
     FractionBox[
      RowBox[{"pdif", "+", "psum"}], "2"]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.548440326354412*^9, 3.548443671664753*^9, 
  3.5484437520373507`*^9, 3.548444210307562*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{"psum", "-", 
    RowBox[{
     SuperscriptBox["pdif", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "s", "+", 
       RowBox[{"dc", " ", 
        SuperscriptBox["s", "2"]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.548440326354412*^9, 3.548443671664753*^9, 
  3.5484437520373507`*^9, 3.5484442103355637`*^9}]
}, Open  ]],

Cell["\<\
where psum = pj + pi. Taking the average over segments:\
\>", "Text",
 CellChangeTimes->{{3.5484403457135196`*^9, 3.548440365741665*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PriceO", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"priceo", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"psum", "\[Rule]", 
       RowBox[{"2", 
        OverscriptBox["p", "_"]}]}], ",", 
      RowBox[{"pdif", "\[Rule]", 
       SqrtBox[
        RowBox[{"2", 
         SubsuperscriptBox["\[Sigma]", "p", "2"]}]]}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.507316113830365*^9, 3.507316193962365*^9}}],

Cell[BoxData[
 RowBox[{
  OverscriptBox["p", "_"], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "s", "+", 
     RowBox[{"dc", " ", 
      SuperscriptBox["s", "2"]}]}], ")"}], " ", 
   SubsuperscriptBox["\[Sigma]", "p", "2"]}]}]], "Output",
 CellChangeTimes->{{3.507316174015365*^9, 3.507316196264365*^9}, 
   3.5073425627096*^9, 3.507488085159151*^9, 3.5075072789763603`*^9, 
   3.508172500208*^9, 3.5083060767755647`*^9, 3.5484436717947607`*^9, 
   3.5484437521553574`*^9, 3.5484442104105678`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Market shares as a function of steady state prices:", "Subsection",
 CellChangeTimes->{{3.5073162332153654`*^9, 3.507316234022365*^9}, {
  3.507318924976365*^9, 3.5073189384273653`*^9}, {3.507487694223151*^9, 
  3.507487726484151*^9}}],

Cell["\<\
The market share of firm i among the young consumers is (see equation 13):\
\>", "Text",
 CellChangeTimes->{{3.5074877086561513`*^9, 3.5074877095681515`*^9}, {
  3.5074880334571514`*^9, 3.507488071059151*^9}, {3.5484404869065957`*^9, 
  3.548440510728958*^9}, {3.548440760737258*^9, 3.548440773857008*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"kappadf", "=", 
  RowBox[{
   FractionBox["1", "N"], "+", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "dY"}], "N"], "/.", 
        RowBox[{"pdif", "\[Rule]", 
         RowBox[{"pj", "-", "pi"}]}]}], ")"}], "-", 
      FractionBox["1", "N"]}], "/.", 
     RowBox[{"pj", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"N", " ", 
         OverscriptBox["p", "_"]}], "-", "pi"}], 
       RowBox[{"N", "-", "1"}]]}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"kappad", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"kappadf", " ", 
      RowBox[{"(", 
       RowBox[{"N", "-", "1"}], ")"}]}], ",", 
     OverscriptBox["p", "_"]}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.507488072388151*^9, 3.507488072760151*^9}, {
   3.5074881208201513`*^9, 3.507488128548151*^9}, {3.507488158638151*^9, 
   3.5074881623531513`*^9}, {3.507488211645151*^9, 3.507488294210151*^9}, {
   3.5074883388631516`*^9, 3.507488382611151*^9}, {3.5074884911301513`*^9, 
   3.5074885281831512`*^9}, {3.507488646265151*^9, 3.507488663881151*^9}, {
   3.5074887559501514`*^9, 3.507488762588151*^9}, 3.5484404842524433`*^9, {
   3.548440537003461*^9, 3.5484405389225707`*^9}, {3.548440691413293*^9, 
   3.5484407219890413`*^9}, {3.5484407565360174`*^9, 
   3.5484407569160395`*^9}, {3.548440878463991*^9, 3.5484408816151714`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "N"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"dc", " ", "s"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "pi"}], "+", 
      OverscriptBox["p", "_"]}], ")"}]}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", "N"}]]}]], "Output",
 CellChangeTimes->{3.5484408830332527`*^9, 3.548443671870765*^9, 
  3.548443752232362*^9, 3.548444210484572*^9}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{"dc", " ", "s"}]}]], "Output",
 CellChangeTimes->{3.5484408830332527`*^9, 3.548443671870765*^9, 
  3.548443752232362*^9, 3.5484442105315747`*^9}]
}, Open  ]],

Cell["The market share of firm i among the whole population:", "Text",
 CellChangeTimes->{{3.507488552751151*^9, 3.5074885640771513`*^9}, {
  3.5484407945441914`*^9, 3.5484408056318254`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"kappamf", "=", 
  RowBox[{
   FractionBox["1", "N"], "+", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"g", " ", "dY"}], "+", 
             RowBox[{"dOi", " ", "dY"}], "+", 
             RowBox[{"dOj", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", "dY"}], ")"}]}]}], ")"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "g"}], ")"}], "N"}]], "/.", 
         RowBox[{"pdif", "\[Rule]", 
          RowBox[{"pj", "-", "pi"}]}]}], ")"}], "/.", 
       RowBox[{"pj", "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"N", " ", 
           OverscriptBox["p", "_"]}], "-", "pi"}], 
         RowBox[{"N", "-", "1"}]]}]}], "]"}], "-", 
     FractionBox["1", "N"]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"kappam", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"kappamf", 
      RowBox[{"(", 
       RowBox[{"N", "-", "1"}], ")"}]}], ",", 
     OverscriptBox["p", "_"]}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.507488072388151*^9, 3.507488072760151*^9}, {
  3.5074881208201513`*^9, 3.507488128548151*^9}, {3.507488158638151*^9, 
  3.5074881623531513`*^9}, {3.507488211645151*^9, 3.507488294210151*^9}, {
  3.5074883388631516`*^9, 3.507488382611151*^9}, {3.5074884911301513`*^9, 
  3.5074885281831512`*^9}, {3.507488575223151*^9, 3.5074886417281513`*^9}, {
  3.5074886727221513`*^9, 3.507488717276151*^9}, {3.507488790782151*^9, 
  3.507488793793151*^9}, {3.548440838146685*^9, 3.5484409197433524`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "N"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "g", "+", "s", "+", 
      RowBox[{"dc", " ", "g", " ", "s"}], "+", 
      RowBox[{"dc", " ", 
       SuperscriptBox["s", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"pi", "-", 
      OverscriptBox["p", "_"]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "g"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "N"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.5074886339431515`*^9, 3.507488642139151*^9}, 
   3.507488688362151*^9, 3.5074887188441515`*^9, 3.5074887944061513`*^9, 
   3.5075072800023603`*^9, 3.508172501222*^9, 3.5083060777615643`*^9, {
   3.5484408419289017`*^9, 3.5484409201623764`*^9}, 3.5484436721857834`*^9, 
   3.5484437523713694`*^9, 3.5484442106005783`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", "g", "+", "s", "+", 
   RowBox[{"dc", " ", "g", " ", "s"}], "+", 
   RowBox[{"dc", " ", 
    SuperscriptBox["s", "2"]}]}], 
  RowBox[{"1", "+", "g"}]]], "Output",
 CellChangeTimes->{{3.5074886339431515`*^9, 3.507488642139151*^9}, 
   3.507488688362151*^9, 3.5074887188441515`*^9, 3.5074887944061513`*^9, 
   3.5075072800023603`*^9, 3.508172501222*^9, 3.5083060777615643`*^9, {
   3.5484408419289017`*^9, 3.5484409201623764`*^9}, 3.5484436721857834`*^9, 
   3.5484437523713694`*^9, 3.548444210641581*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Consumers' expected costs (not in the paper)", "Subsection",
 CellChangeTimes->{{3.5073162332153654`*^9, 3.507316234022365*^9}, {
  3.507318924976365*^9, 3.5073189384273653`*^9}, {3.548440964393906*^9, 
  3.548441005352249*^9}}],

Cell[TextData[{
 "Consumer discounted expected costs are ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"Cy", "+", 
      RowBox[{
       SubscriptBox["\[Delta]", "c"], "Co"}]}], 
     RowBox[{"1", "+", 
      SubscriptBox["\[Delta]", "c"]}]], ",", 
    RowBox[{
    "where", " ", "g", " ", "is", " ", "the", " ", "share", " ", "of", " ", 
     "young", " ", "consumers"}], ",", 
    RowBox[{"and", " ", "Cy"}], ",", 
    RowBox[{
    "Co", " ", "are", " ", "the", " ", "costs", " ", "borne", " ", "by", " ", 
     "young", " ", "and", " ", "old", " ", "consumers"}]}], 
   TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.5073189728783655`*^9, 3.507319016990365*^9}, {
  3.54844147899534*^9, 3.5484414923621044`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ccd", "=", 
  RowBox[{"FullSimplify", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"TptCostY", "+", "PriceY"}], ")"}], "+", 
     RowBox[{"dc", 
      RowBox[{"(", 
       RowBox[{"TptCostO", "+", "PriceO", "+", "SwtCostO"}], ")"}]}]}], 
    RowBox[{"1", "+", "dc"}]], "]"}]}]], "Input",
 CellChangeTimes->{{3.5073190760623655`*^9, 3.507319093926365*^9}, {
  3.507319129643365*^9, 3.507319163624365*^9}, {3.5073192588073654`*^9, 
  3.507319278377365*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", "dc", "+", 
   RowBox[{"2", " ", "dc", " ", "s"}], "-", 
   RowBox[{"dc", " ", 
    SuperscriptBox["s", "2"]}], "+", 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "dc"}], ")"}], " ", 
    OverscriptBox["p", "_"]}], "-", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"dc", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"s", " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", 
            RowBox[{"dc", " ", "s"}]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
    SubsuperscriptBox["\[Sigma]", "p", "2"]}]}], 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "dc"}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.507319271652365*^9, 3.5073192792863655`*^9}, 
   3.5073425630196*^9, 3.5074880854881516`*^9, 3.507507280364361*^9, 
   3.508172501519*^9, 3.5083060780855646`*^9, 3.548443672411796*^9, 
   3.548443752574381*^9, 3.5484442107095847`*^9}]
}, Open  ]],

Cell["Output for Matlab", "Text",
 CellChangeTimes->{{3.5484413978686996`*^9, 3.5484414047790947`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"Ccd", ",", 
    OverscriptBox["p", "_"]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ToMatlab", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"Ccd", ",", 
     SubsuperscriptBox["\[Sigma]", "p", "2"]}], "]"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ToMatlab", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Ccd", "-", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"Ccd", ",", 
       SubsuperscriptBox["\[Sigma]", "p", "2"]}], "]"}], 
     SubsuperscriptBox["\[Sigma]", "p", "2"]}], "-", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"Ccd", ",", 
       OverscriptBox["p", "_"]}], "]"}], 
     OverscriptBox["p", "_"]}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.507319303851365*^9, 3.5073193491423655`*^9}, {
  3.507319394560365*^9, 3.5073193948593655`*^9}, {3.5075079283863606`*^9, 
  3.5075079399573603`*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.507319333502365*^9, 3.507319350214365*^9}, {
   3.507319387620365*^9, 3.5073193956113653`*^9}, 3.5073425630586*^9, 
   3.5074880855231514`*^9, 3.5075072804003606`*^9, 3.5075079403323603`*^9, 
   3.508172501541*^9, 3.5083060781235647`*^9, 3.548443672463799*^9, 
   3.5484437526563854`*^9, 3.548444210773588*^9}],

Cell[BoxData["\<\"(-1/2).*(1+dc).^(-1).*(1+dc.*(1+s.*(2+dc.*s)));\\n\"\>"], \
"Output",
 CellChangeTimes->{{3.507319333502365*^9, 3.507319350214365*^9}, {
   3.507319387620365*^9, 3.5073193956113653`*^9}, 3.5073425630586*^9, 
   3.5074880855231514`*^9, 3.5075072804003606`*^9, 3.5075079403323603`*^9, 
   3.508172501541*^9, 3.5083060781235647`*^9, 3.548443672463799*^9, 
   3.5484437526563854`*^9, 3.5484442108085904`*^9}],

Cell[BoxData["\<\"(4+4.*dc).^(-1).*(1+dc+2.*dc.*s+(-1).*dc.*s.^2);\\n\"\>"], \
"Output",
 CellChangeTimes->{{3.507319333502365*^9, 3.507319350214365*^9}, {
   3.507319387620365*^9, 3.5073193956113653`*^9}, 3.5073425630586*^9, 
   3.5074880855231514`*^9, 3.5075072804003606`*^9, 3.5075079403323603`*^9, 
   3.508172501541*^9, 3.5083060781235647`*^9, 3.548443672463799*^9, 
   3.5484437526563854`*^9, 3.548444210882595*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Consumers' average costs:", "Subsection"]], \
"Subsubsection",
 CellChangeTimes->{{3.5073162332153654`*^9, 3.507316234022365*^9}, {
  3.507318924976365*^9, 3.5073189384273653`*^9}, {3.5073424252486*^9, 
  3.5073424261796*^9}, {3.548441029095607*^9, 3.5484410293516216`*^9}}],

Cell[TextData[{
 "Consumer average costs are ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"gCy", "+", "Co"}], 
    RowBox[{"1", "+", "g"}]], TraditionalForm]]],
 ", where g is the share of young consumers, and Cy,Co are the costs borne by \
young and old consumers (equation 19):"
}], "Text",
 CellChangeTimes->{{3.5073189728783655`*^9, 3.507319016990365*^9}, {
  3.5073424308566*^9, 3.5073424394256*^9}, {3.5484410398202205`*^9, 
  3.5484411003576827`*^9}, {3.548442699137128*^9, 3.548442717776194*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cca", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     FractionBox[
      RowBox[{
       RowBox[{"g", 
        RowBox[{"(", 
         RowBox[{"TptCostY", "+", "PriceY"}], ")"}]}], "+", 
       RowBox[{"(", 
        RowBox[{"TptCostO", "+", "PriceO", "+", "SwtCostO"}], ")"}]}], 
      RowBox[{"1", "+", "g"}]], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      OverscriptBox["p", "_"], ",", 
      SubsuperscriptBox["\[Sigma]", "p", "2"]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5073190760623655`*^9, 3.507319093926365*^9}, {
  3.507319129643365*^9, 3.507319163624365*^9}, {3.5073192588073654`*^9, 
  3.507319278377365*^9}, {3.5073424445206003`*^9, 3.5073424616886*^9}, {
  3.508173091225*^9, 3.508173109977*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"1", "+", "g", "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "s"}], ")"}], " ", "s"}]}], 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "g"}], ")"}]}]], "+", 
  OverscriptBox["p", "_"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "-", "g", "-", 
      RowBox[{"2", " ", "s"}], "+", 
      RowBox[{"dc", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"dc", " ", "g"}]}], ")"}], " ", 
       SuperscriptBox["s", "2"]}]}], ")"}], " ", 
    SubsuperscriptBox["\[Sigma]", "p", "2"]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "g"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.507319271652365*^9, 3.5073192792863655`*^9}, 
   3.5073425638956003`*^9, 3.5074880860961514`*^9, 3.507507281008361*^9, 
   3.50817250221*^9, {3.508173102354*^9, 3.508173110493*^9}, 
   3.5083060786885643`*^9, 3.548443672787818*^9, 3.548443753024407*^9, 
   3.5484442109505987`*^9}]
}, Open  ]],

Cell["Output for matlab: SingleProduct.m", "Text",
 CellChangeTimes->{{3.5484412045476427`*^9, 3.5484412097139378`*^9}, {
  3.5484412727835455`*^9, 3.5484412806869974`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"Cca", ",", 
    OverscriptBox["p", "_"]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"Cca", ",", 
    SubsuperscriptBox["\[Sigma]", "p", "2"]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Cca", "-", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"Cca", ",", 
      SubsuperscriptBox["\[Sigma]", "p", "2"]}], "]"}], 
    SubsuperscriptBox["\[Sigma]", "p", "2"]}], "-", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"Cca", ",", 
      OverscriptBox["p", "_"]}], "]"}], 
    OverscriptBox["p", "_"]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ToMatlab", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"Cca", ",", 
     SubsuperscriptBox["\[Sigma]", "p", "2"]}], "]"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ToMatlab", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Cca", "-", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"Cca", ",", 
       SubsuperscriptBox["\[Sigma]", "p", "2"]}], "]"}], 
     SubsuperscriptBox["\[Sigma]", "p", "2"]}], "-", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"Cca", ",", 
       OverscriptBox["p", "_"]}], "]"}], 
     OverscriptBox["p", "_"]}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.507319303851365*^9, 3.5073193491423655`*^9}, {
  3.507319394560365*^9, 3.5073193948593655`*^9}, {3.5073424659656*^9, 
  3.5073424756796*^9}, {3.5075077174253607`*^9, 3.507507725890361*^9}, {
  3.508172477481*^9, 3.508172488958*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.507319333502365*^9, 3.507319350214365*^9}, {
   3.507319387620365*^9, 3.5073193956113653`*^9}, 3.5073425639856*^9, 
   3.5074880861361513`*^9, 3.5075072810913606`*^9, 3.5075077296013603`*^9, 
   3.5081725022349997`*^9, 3.5083060787225647`*^9, 3.5484436729198256`*^9, 
   3.548443753092411*^9, 3.5484442110176024`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"1", "+", "g", "+", 
    RowBox[{"2", " ", "s"}], "+", 
    RowBox[{"dc", " ", 
     RowBox[{"(", 
      RowBox[{"2", "-", 
       RowBox[{"dc", " ", "g"}]}], ")"}], " ", 
     SuperscriptBox["s", "2"]}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "g"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.507319333502365*^9, 3.507319350214365*^9}, {
   3.507319387620365*^9, 3.5073193956113653`*^9}, 3.5073425639856*^9, 
   3.5074880861361513`*^9, 3.5075072810913606`*^9, 3.5075077296013603`*^9, 
   3.5081725022349997`*^9, 3.5083060787225647`*^9, 3.5484436729198256`*^9, 
   3.548443753092411*^9, 3.548444211066605*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", "g", "+", 
   RowBox[{"2", " ", "s"}], "-", 
   SuperscriptBox["s", "2"]}], 
  RowBox[{"4", "+", 
   RowBox[{"4", " ", "g"}]}]]], "Output",
 CellChangeTimes->{{3.507319333502365*^9, 3.507319350214365*^9}, {
   3.507319387620365*^9, 3.5073193956113653`*^9}, 3.5073425639856*^9, 
   3.5074880861361513`*^9, 3.5075072810913606`*^9, 3.5075077296013603`*^9, 
   3.5081725022349997`*^9, 3.5083060787225647`*^9, 3.5484436729198256`*^9, 
   3.548443753092411*^9, 3.5484442111336093`*^9}],

Cell[BoxData["\<\"(-1/2).*(1+g).^(-1).*(1+g+2.*s+dc.*(2+(-1).*dc.*g).*s.^2);\\\
n\"\>"], "Output",
 CellChangeTimes->{{3.507319333502365*^9, 3.507319350214365*^9}, {
   3.507319387620365*^9, 3.5073193956113653`*^9}, 3.5073425639856*^9, 
   3.5074880861361513`*^9, 3.5075072810913606`*^9, 3.5075077296013603`*^9, 
   3.5081725022349997`*^9, 3.5083060787225647`*^9, 3.5484436729198256`*^9, 
   3.548443753092411*^9, 3.548444211200613*^9}],

Cell[BoxData["\<\"(4+4.*g).^(-1).*(1+g+2.*s+(-1).*s.^2);\\n\"\>"], "Output",
 CellChangeTimes->{{3.507319333502365*^9, 3.507319350214365*^9}, {
   3.507319387620365*^9, 3.5073193956113653`*^9}, 3.5073425639856*^9, 
   3.5074880861361513`*^9, 3.5075072810913606`*^9, 3.5075077296013603`*^9, 
   3.5081725022349997`*^9, 3.5083060787225647`*^9, 3.5484436729198256`*^9, 
   3.548443753092411*^9, 3.548444211269617*^9}]
}, Open  ]],

Cell["If we consider only switching and transport (equation 15):", "Text",
 CellChangeTimes->{{3.5081730336949997`*^9, 3.508173039124*^9}, {
  3.548441518583604*^9, 3.5484415228228464`*^9}, {3.5484427400944705`*^9, 
  3.548442752782196*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ETSC", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"TptCostO", "+", "SwtCostO", "+", 
        RowBox[{"g", " ", "TptCostY"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", "g"}], ")"}]}], "]"}], ",", 
    SubsuperscriptBox["\[Sigma]", "p", "2"]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.505190633074753*^9, 3.505190773883753*^9, {3.5051923294317527`*^9, 
   3.5051924158877525`*^9}, 3.5051928127887526`*^9, {3.548444061748065*^9, 
   3.548444068467449*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"1", "+", "g", "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "s"}], ")"}], " ", "s"}]}], 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "g"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"g", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"dc", " ", "s"}]}], ")"}], "2"]}]}], ")"}], " ", 
    SubsuperscriptBox["\[Sigma]", "p", "2"]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "g"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.505192359297753*^9, 3.5051924164447527`*^9}, 
   3.505192551916753*^9, 3.5051928145267525`*^9, 3.5051946173807526`*^9, 
   3.505195901419753*^9, 3.5051968066417527`*^9, 3.5070617946146*^9, 
   3.5073063059963655`*^9, 3.507488087723151*^9, 3.5075072822963605`*^9, 
   3.508172503442*^9, 3.5083060799995646`*^9, 3.5484436737908745`*^9, 
   3.548443754196474*^9, 3.5484440925688276`*^9, 3.548444211391624*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{
      RowBox[{"g", 
       RowBox[{"(", "PriceY", ")"}]}], "+", 
      RowBox[{"(", "PriceO", ")"}]}], 
     RowBox[{"1", "+", "g"}]], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     OverscriptBox["p", "_"], ",", 
     SubsuperscriptBox["\[Sigma]", "p", "2"]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.50817313842*^9, 3.50817314421*^9}}],

Cell[BoxData[
 RowBox[{
  OverscriptBox["p", "_"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "g", "+", "s", "+", 
      RowBox[{"dc", " ", "g", " ", "s"}], "+", 
      RowBox[{"dc", " ", 
       SuperscriptBox["s", "2"]}]}], ")"}], " ", 
    SubsuperscriptBox["\[Sigma]", "p", "2"]}], 
   RowBox[{"1", "+", "g"}]]}]], "Output",
 CellChangeTimes->{3.508173145782*^9, 3.5083060791205645`*^9, 
  3.54844367334785*^9, 3.5484437535994396`*^9, 3.548444211475629*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Third alternative weight both (not in the paper)", "Subsubsection",
 CellChangeTimes->{{3.5073162332153654`*^9, 3.507316234022365*^9}, {
  3.507318924976365*^9, 3.5073189384273653`*^9}, {3.5073424252486*^9, 
  3.5073424261796*^9}, {3.5073425001976*^9, 3.5073425061196003`*^9}, {
  3.54844149664835*^9, 3.548441499735526*^9}}],

Cell[TextData[{
 "Consumer average costs are given by ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"gCy", "+", 
     RowBox[{
      SubscriptBox["\[Delta]", "c"], "Co"}]}], 
    RowBox[{
     SubscriptBox["\[Delta]", "c"], "+", "g"}]], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->{{3.5073189728783655`*^9, 3.507319016990365*^9}, {
   3.5073424308566*^9, 3.5073424394256*^9}, {3.5073425141256*^9, 
   3.5073425217916*^9}, 3.5073427242216*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cc3", "=", 
  RowBox[{"FullSimplify", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"g", 
      RowBox[{"(", 
       RowBox[{"TptCostY", "+", "PriceY"}], ")"}]}], "+", 
     RowBox[{"dc", 
      RowBox[{"(", 
       RowBox[{"TptCostO", "+", "PriceO", "+", "SwtCostO"}], ")"}]}]}], 
    RowBox[{"dc", "+", "g"}]], "]"}]}]], "Input",
 CellChangeTimes->{{3.5073190760623655`*^9, 3.507319093926365*^9}, {
  3.507319129643365*^9, 3.507319163624365*^9}, {3.5073192588073654`*^9, 
  3.507319278377365*^9}, {3.5073424445206003`*^9, 3.5073424616886*^9}, {
  3.5073425258356*^9, 3.5073425290396*^9}, {3.5073427299656*^9, 
  3.5073427300996*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"dc", "+", "g", "+", 
   RowBox[{"2", " ", "dc", " ", "s"}], "-", 
   RowBox[{"dc", " ", 
    SuperscriptBox["s", "2"]}], "+", 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{"dc", "+", "g"}], ")"}], " ", 
    OverscriptBox["p", "_"]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "g"}], "+", 
      RowBox[{"dc", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"s", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            RowBox[{"dc", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "g"}], ")"}], " ", "s"}]}], ")"}]}]}],
         ")"}]}]}], ")"}], " ", 
    SubsuperscriptBox["\[Sigma]", "p", "2"]}]}], 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{"dc", "+", "g"}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.507319271652365*^9, 3.5073192792863655`*^9}, 
   3.5073425648016*^9, 3.5073427308676*^9, 3.5074880870611515`*^9, 
   3.5075072818223605`*^9, 3.508172502999*^9, 3.5083060796935644`*^9, 
   3.5484436735798626`*^9, 3.5484437538774557`*^9, 3.548444211542632*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"Cc3", ",", 
    OverscriptBox["p", "_"]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ToMatlab", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"Cc3", ",", 
     SubsuperscriptBox["\[Sigma]", "p", "2"]}], "]"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ToMatlab", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Cc3", "-", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"Cc3", ",", 
       SubsuperscriptBox["\[Sigma]", "p", "2"]}], "]"}], 
     SubsuperscriptBox["\[Sigma]", "p", "2"]}], "-", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"Cc3", ",", 
       OverscriptBox["p", "_"]}], "]"}], 
     OverscriptBox["p", "_"]}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.507319303851365*^9, 3.5073193491423655`*^9}, {
  3.507319394560365*^9, 3.5073193948593655`*^9}, {3.5073424659656*^9, 
  3.5073424756796*^9}, {3.5073425345566*^9, 3.5073425438255997`*^9}, {
  3.507508026987361*^9, 3.507508039029361*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.507319333502365*^9, 3.507319350214365*^9}, {
   3.507319387620365*^9, 3.5073193956113653`*^9}, 3.5073425648346*^9, 
   3.5073427323646*^9, 3.507488087171151*^9, 3.5075072818553605`*^9, 
   3.5075080394513607`*^9, 3.508172503071*^9, 3.5083060797775645`*^9, 
   3.5484436736268654`*^9, 3.548443753989462*^9, 3.548444211606636*^9}],

Cell[BoxData["\<\"(-1/2).*(dc+g).^(-1).*(g+dc.*(1+s.*(2+(-1).*dc.*((-2)+g).*s)\
));\\n\"\>"], "Output",
 CellChangeTimes->{{3.507319333502365*^9, 3.507319350214365*^9}, {
   3.507319387620365*^9, 3.5073193956113653`*^9}, 3.5073425648346*^9, 
   3.5073427323646*^9, 3.507488087171151*^9, 3.5075072818553605`*^9, 
   3.5075080394513607`*^9, 3.508172503071*^9, 3.5083060797775645`*^9, 
   3.5484436736268654`*^9, 3.548443753989462*^9, 3.548444211639638*^9}],

Cell[BoxData["\<\"(1/4).*(dc+g).^(-1).*(g+dc.*(1+(-1).*((-2)+s).*s));\\n\"\>"]\
, "Output",
 CellChangeTimes->{{3.507319333502365*^9, 3.507319350214365*^9}, {
   3.507319387620365*^9, 3.5073193956113653`*^9}, 3.5073425648346*^9, 
   3.5073427323646*^9, 3.507488087171151*^9, 3.5075072818553605`*^9, 
   3.5075080394513607`*^9, 3.508172503071*^9, 3.5083060797775645`*^9, 
   3.5484436736268654`*^9, 3.548443753989462*^9, 3.5484442117146425`*^9}]
}, Open  ]],

Cell["\<\
In the three cases above, costs are decreasing in price variance. \
\>", "Text",
 CellChangeTimes->{{3.5073427631736*^9, 3.5073427789976*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Production costs", "Subsection",
 CellChangeTimes->{{3.505187901584753*^9, 3.5051879338097525`*^9}, {
   3.505187982633753*^9, 3.505187990428753*^9}, 3.505192712008753*^9, {
   3.505192758400753*^9, 3.505192777923753*^9}}],

Cell["\<\
In equilibrium, the share of the share of i in segment i-j is:\
\>", "Text",
 CellChangeTimes->{{3.505192873098753*^9, 3.505192877863753*^9}, {
  3.505229284948753*^9, 3.5052292930597525`*^9}, {3.5484427889242635`*^9, 
  3.5484428022840276`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xij", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"g", " ", "dY"}], "+", 
       RowBox[{"dY", " ", "dOi"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "dY"}], ")"}], "dOj"}]}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", "g"}], ")"}]}], ",", "pdif"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.505228688132753*^9, 3.505228775744753*^9}, 
   3.505229644400753*^9, 3.505229675518753*^9, {3.54844306387799*^9, 
   3.5484430678612175`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], "+", 
  FractionBox[
   RowBox[{"pdif", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "g", "+", 
      RowBox[{"dc", " ", "g", " ", "s"}], "+", 
      RowBox[{"s", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"dc", " ", "s"}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "g"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.505228742487753*^9, 3.5052287767767525`*^9}, {
   3.505229693599753*^9, 3.505229706002753*^9}, 3.5070619086636*^9, 
   3.507306306148365*^9, 3.5074880879191513`*^9, 3.5075072856343603`*^9, 
   3.508172506825*^9, 3.5083060830345645`*^9, 3.548443070438365*^9, 
   3.548443680612265*^9, 3.548443754291479*^9, 3.5484442117836466`*^9}]
}, Open  ]],

Cell["Adding up segments linked to i", "Text",
 CellChangeTimes->{{3.505229300488753*^9, 3.5052293580857525`*^9}, {
  3.5484427714852657`*^9, 3.5484427721893063`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    FractionBox["2", "N"], " ", "xij"}], "/.", 
   RowBox[{"pdif", "\[Rule]", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["p", "_"], 
      RowBox[{"-", "i"}]], "-", 
     SubscriptBox["p", "i"]}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"sharei", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{
           FractionBox["2", "N"], " ", "xij"}], "/.", 
          RowBox[{"pdif", "\[Rule]", 
           RowBox[{
            SubscriptBox[
             OverscriptBox["p", "_"], 
             RowBox[{"-", "i"}]], "-", 
            SubscriptBox["p", "i"]}]}]}], "]"}], "/.", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["p", "_"], 
          RowBox[{"-", "i"}]], "\[Rule]", 
         RowBox[{
          RowBox[{
           FractionBox["N", 
            RowBox[{"N", "-", "1"}]], 
           OverscriptBox["p", "_"]}], "-", 
          FractionBox[
           SubscriptBox["p", "i"], 
           RowBox[{"N", "-", "1"}]]}]}]}], ",", 
       RowBox[{"N", ">", "2"}]}], "]"}], "/.", 
     RowBox[{
      OverscriptBox["p", "_"], "->", 
      RowBox[{
       SubscriptBox["p", "i"], "-", "pdem"}]}]}], ",", "pdem"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.505228914587753*^9, 3.505229000485753*^9}, 
   3.5052290442207527`*^9, {3.505229363647753*^9, 3.5052294044137526`*^9}, {
   3.5052294385057526`*^9, 3.505229447355753*^9}, {3.5052294997747526`*^9, 
   3.505229552094753*^9}, {3.505229650239753*^9, 3.505229700780753*^9}, {
   3.5484429172146015`*^9, 3.548442917628625*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "g", "+", "s", "+", 
       RowBox[{"dc", " ", "g", " ", "s"}], "+", 
       RowBox[{"dc", " ", 
        SuperscriptBox["s", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["p", "i"]}], "+", 
       SubscriptBox[
        OverscriptBox["p", "_"], 
        RowBox[{"-", "i"}]]}], ")"}]}], 
    RowBox[{"1", "+", "g"}]]}], "N"]], "Output",
 CellChangeTimes->{3.5484430755326567`*^9, 3.5484436807032704`*^9, 
  3.548443754395485*^9, 3.5484442118546505`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "N"], "-", 
  FractionBox[
   RowBox[{"pdem", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "g", "+", "s", "+", 
      RowBox[{"dc", " ", "g", " ", "s"}], "+", 
      RowBox[{"dc", " ", 
       SuperscriptBox["s", "2"]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "g"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "N"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.5484430755326567`*^9, 3.5484436807032704`*^9, 
  3.548443754395485*^9, 3.5484442118976526`*^9}]
}, Open  ]],

Cell[TextData[{
 "where pdem=",
 Cell[BoxData[
  SubscriptBox["p", "i"]],
  CellChangeTimes->{{3.505228914587753*^9, 3.505229000485753*^9}, 
    3.5052290442207527`*^9, {3.505229363647753*^9, 3.5052294044137526`*^9}, {
    3.5052294385057526`*^9, 3.505229447355753*^9}, {3.5052294997747526`*^9, 
    3.505229552094753*^9}, {3.505229650239753*^9, 3.505229700780753*^9}, {
    3.5484429172146015`*^9, 3.548442917628625*^9}}],
 "-",
 Cell[BoxData[
  SubscriptBox[
   OverscriptBox["p", "_"], 
   RowBox[{"-", "i"}]]],
  CellChangeTimes->{{3.505228914587753*^9, 3.505229000485753*^9}, 
    3.5052290442207527`*^9, {3.505229363647753*^9, 3.5052294044137526`*^9}, {
    3.5052294385057526`*^9, 3.505229447355753*^9}, {3.5052294997747526`*^9, 
    3.505229552094753*^9}, {3.505229650239753*^9, 3.505229700780753*^9}, {
    3.5484429172146015`*^9, 3.548442917628625*^9}}],
 ". The average production cost is: ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "1"}], "N"], 
   RowBox[{
    SubscriptBox["c", "i"], 
    SubscriptBox["share", "i"]}]}]],
  CellChangeTimes->{{3.5052295872667527`*^9, 3.5052295990127525`*^9}, {
   3.505229694165753*^9, 3.505229706114753*^9}, {3.5052299235927525`*^9, 
   3.505229939735753*^9}}],
 ", which yields equation (16): "
}], "Text",
 CellChangeTimes->{{3.5484429314804173`*^9, 3.548443022581628*^9}, {
  3.5484433453420887`*^9, 3.5484434016733108`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PC", "=", 
  RowBox[{
   OverscriptBox["c", "_"], "+", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"sharei", ",", "pdem"}], "]"}], 
    RowBox[{"(", 
     RowBox[{"N", "-", "1"}], ")"}], 
    SubscriptBox["\[Sigma]", "cp"]}]}]}]], "Input",
 CellChangeTimes->{{3.5484431391902976`*^9, 3.54844326580754*^9}}],

Cell[BoxData[
 RowBox[{
  OverscriptBox["c", "_"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "g", "+", "s", "+", 
      RowBox[{"dc", " ", "g", " ", "s"}], "+", 
      RowBox[{"dc", " ", 
       SuperscriptBox["s", "2"]}]}], ")"}], " ", 
    SubscriptBox["\[Sigma]", "cp"]}], 
   RowBox[{"1", "+", "g"}]]}]], "Output",
 CellChangeTimes->{{3.5052295872667527`*^9, 3.5052295990127525`*^9}, {
   3.505229694165753*^9, 3.505229706114753*^9}, {3.5052299235927525`*^9, 
   3.505229939735753*^9}, 3.5070619093666*^9, 3.5073063066773653`*^9, 
   3.507488088481151*^9, 3.5075072861673603`*^9, 3.508172507361*^9, 
   3.5083060830855646`*^9, {3.548443242981234*^9, 3.548443266484578*^9}, 
   3.548443680907282*^9, 3.5484437545584946`*^9, 3.5484442119656568`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Social Planner's Problem", "Subsection",
 CellChangeTimes->{{3.5052306958587527`*^9, 3.505230701896753*^9}, {
  3.5484449035612135`*^9, 3.548444906053356*^9}}],

Cell["\<\
The (constrained) social planner chooses the vector of prices that minimize \
the total cost per-period:\
\>", "Text",
 CellChangeTimes->{{3.505230791693753*^9, 3.505230815514753*^9}, {
  3.5484434838300095`*^9, 3.5484435068683276`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"minobj", "=", 
  RowBox[{"PC", "+", "ETSC"}]}]], "Input",
 CellChangeTimes->{{3.505230709461753*^9, 3.5052307381157527`*^9}, {
  3.505230776110753*^9, 3.505230782192753*^9}, {3.5484435142137475`*^9, 
  3.5484435253663855`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"1", "+", "g", "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "s"}], ")"}], " ", "s"}]}], 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "g"}], ")"}]}]], "+", 
  OverscriptBox["c", "_"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "g", "+", "s", "+", 
      RowBox[{"dc", " ", "g", " ", "s"}], "+", 
      RowBox[{"dc", " ", 
       SuperscriptBox["s", "2"]}]}], ")"}], " ", 
    SubscriptBox["\[Sigma]", "cp"]}], 
   RowBox[{"1", "+", "g"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"g", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"dc", " ", "s"}]}], ")"}], "2"]}]}], ")"}], " ", 
    SubsuperscriptBox["\[Sigma]", "p", "2"]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "g"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.5052307830367527`*^9, 3.5070619094035997`*^9, 
  3.507306306716365*^9, 3.507488088506151*^9, 3.5075072861943607`*^9, 
  3.5081725073859997`*^9, 3.5083060831125646`*^9, 3.5484436874946585`*^9, 
  3.548443758867741*^9, 3.5484442120256605`*^9}]
}, Open  ]],

Cell[TextData[{
 "This function is maximized when prices are aligned with costs, i.e., ",
 StyleBox[Cell[BoxData[
  RowBox[{
   SubscriptBox["p", "i"], "-", 
   OverscriptBox["p", "_"]}]], "Input",
  CellChangeTimes->{{3.505228914587753*^9, 3.505229000485753*^9}, 
    3.5052290442207527`*^9, {3.505229363647753*^9, 3.5052294044137526`*^9}, {
    3.5052294385057526`*^9, 3.505229447355753*^9}, {3.5052294997747526`*^9, 
    3.505229552094753*^9}, {3.505229650239753*^9, 3.505229700780753*^9}, {
    3.5484429172146015`*^9, 3.548442917628625*^9}}], "Input"],
 StyleBox["=\[Gamma](", "Input"],
 StyleBox[Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "i"], "-", 
   OverscriptBox["c", "_"]}]], "Input",
  CellChangeTimes->{{3.505228914587753*^9, 3.505229000485753*^9}, 
    3.5052290442207527`*^9, {3.505229363647753*^9, 3.5052294044137526`*^9}, {
    3.5052294385057526`*^9, 3.505229447355753*^9}, {3.5052294997747526`*^9, 
    3.505229552094753*^9}, {3.505229650239753*^9, 3.505229700780753*^9}, {
    3.5484429172146015`*^9, 3.548442917628625*^9}}], "Input"],
 StyleBox[").", "Input"]
}], "Text",
 CellChangeTimes->{{3.5052308276877527`*^9, 3.505230871669753*^9}, {
  3.548443790587555*^9, 3.548443809690648*^9}, {3.5484438578013997`*^9, 
  3.5484439283914375`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"minobj2", "=", 
  RowBox[{"minobj", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Sigma]", "cp"], "\[Rule]", 
      RowBox[{"\[Gamma]", " ", 
       SubsuperscriptBox["\[Sigma]", "c", "2"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Sigma]", "p"], "->", 
      RowBox[{"\[Gamma]", " ", 
       SubscriptBox["\[Sigma]", "c"]}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.5052308794467525`*^9, 3.505230883089753*^9}, {
  3.505230914589753*^9, 3.505230972492753*^9}, {3.505231037093753*^9, 
  3.505231041570753*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"1", "+", "g", "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "s"}], ")"}], " ", "s"}]}], 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "g"}], ")"}]}]], "+", 
  OverscriptBox["c", "_"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "g", "+", "s", "+", 
      RowBox[{"dc", " ", "g", " ", "s"}], "+", 
      RowBox[{"dc", " ", 
       SuperscriptBox["s", "2"]}]}], ")"}], " ", "\[Gamma]", " ", 
    SubsuperscriptBox["\[Sigma]", "c", "2"]}], 
   RowBox[{"1", "+", "g"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"g", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"dc", " ", "s"}]}], ")"}], "2"]}]}], ")"}], " ", 
    SuperscriptBox["\[Gamma]", "2"], " ", 
    SubsuperscriptBox["\[Sigma]", "c", "2"]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "g"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.505230973772753*^9, 3.505231010408753*^9, 
  3.505231042311753*^9, 3.5070619094216003`*^9, 3.5073063067373652`*^9, 
  3.5074880885281515`*^9, 3.5075072862213607`*^9, 3.5081725074119997`*^9, 
  3.5083060831365643`*^9, 3.548443943582306*^9, 3.548444212093664*^9}]
}, Open  ]],

Cell["\<\
This function is convex in \[Gamma], the minimum is attained when the first \
order condition is satisfied:\
\>", "Text",
 CellChangeTimes->{{3.548443958982187*^9, 3.548443984356638*^9}}],

Cell["How disperse should prices be?", "Text",
 CellChangeTimes->{{3.505231027131753*^9, 3.505231033915753*^9}, {
  3.505231085330753*^9, 3.505231087530753*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SPsol", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{"minobj2", ",", "\[Gamma]"}], "]"}], "\[Equal]", "0"}], ",", 
     "\[Gamma]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.505231044459753*^9, 3.505231112568753*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\[Gamma]", "\[Rule]", 
    FractionBox[
     RowBox[{"1", "+", "g", "+", "s", "+", 
      RowBox[{"dc", " ", "g", " ", "s"}], "+", 
      RowBox[{"dc", " ", 
       SuperscriptBox["s", "2"]}]}], 
     RowBox[{"1", "+", 
      RowBox[{"g", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"dc", " ", "s"}]}], ")"}], "2"]}]}]]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5484439948172364`*^9, 3.5484442121656685`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Optimal Pass-through \[Gamma] (Appendix B)\
\>", "Subsubsection",
 CellChangeTimes->{{3.5484442485887513`*^9, 3.548444316521637*^9}}],

Cell["The optimal pass-through is decreasing in g.", "Text",
 CellChangeTimes->{{3.548444920502183*^9, 3.548444932676879*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"\[Gamma]", "/.", 
     RowBox[{"SPsol", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ",", "g"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.548445029218401*^9, 3.5484450560979385`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"s", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"dc", " ", "s"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"dc", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"s", " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", 
            RowBox[{"dc", " ", "s"}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"g", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"dc", " ", "s"}]}], ")"}], "2"]}]}], ")"}], 
    "2"]]}]], "Output",
 CellChangeTimes->{{3.548445039993017*^9, 3.5484450565279627`*^9}}]
}, Open  ]],

Cell["It ranges from one half to 3:", "Text",
 CellChangeTimes->{{3.5484450968312683`*^9, 3.548445135517481*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SPsol", " ", "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s", " ", "\[Rule]", " ", "1"}], ",", " ", 
    RowBox[{"dc", " ", "\[Rule]", " ", "1"}], ",", " ", 
    RowBox[{"g", " ", "\[Rule]", " ", "100000000"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\[Gamma]", "\[Rule]", 
    FractionBox["200000003", "400000001"]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.548445115717348*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SPsol", " ", "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s", " ", "\[Rule]", " ", "1"}], ",", " ", 
    RowBox[{"dc", " ", "\[Rule]", " ", "1"}], ",", " ", 
    RowBox[{"g", " ", "\[Rule]", " ", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{3.5484451499833083`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\[Gamma]", "\[Rule]", "3"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.548445156693692*^9}]
}, Open  ]],

Cell[TextData[{
 "The intuition that the optimum is achieved by making the consumers \
internalize the total economic costs of their actions holds only if switching \
costs are 0 or if ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", "c"], TraditionalForm]]],
 "g=1"
}], "Text",
 CellChangeTimes->{{3.548445508705826*^9, 3.548445530129051*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SPsol", "/.", 
  RowBox[{"s", "\[Rule]", "0"}]}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"SPsol", "/.", 
   RowBox[{"g", "\[Rule]", 
    RowBox[{"1", "/", "dc"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5484455505662203`*^9, 3.5484455686092525`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\[Gamma]", "\[Rule]", "1"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.548445546819006*^9, 3.5484455692402887`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\[Gamma]", "\[Rule]", "1"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.548445546819006*^9, 3.5484455692582893`*^9}}]
}, Open  ]],

Cell["\<\
Behavior of optimal \[Gamma] as g goes to zero\
\>", "Text",
 CellChangeTimes->{{3.54844593326711*^9, 3.548445933780139*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"\[Gamma]", "/.", 
    RowBox[{"SPsol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ",", 
   RowBox[{"g", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.548445830745246*^9, 3.5484458792230186`*^9}, 
   3.548445942292626*^9}],

Cell[BoxData[
 RowBox[{"1", "+", "s", "+", 
  RowBox[{"dc", " ", 
   SuperscriptBox["s", "2"]}]}]], "Output",
 CellChangeTimes->{3.5484459437237077`*^9}]
}, Open  ]],

Cell["\<\
Behavior of optimal \[Gamma] as g goes to infinity\
\>", "Text",
 CellChangeTimes->{{3.5484458953629417`*^9, 3.548445913892001*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"\[Gamma]", "/.", 
    RowBox[{"SPsol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ",", 
   RowBox[{"g", "\[Rule]", "\[Infinity]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.548445830745246*^9, 3.5484458792230186`*^9}}],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"1", "+", 
   RowBox[{"dc", " ", "s"}]}]]], "Output",
 CellChangeTimes->{{3.548445873523692*^9, 3.548445880591097*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1664, 915},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 144, 2, 83, "Title"],
Cell[737, 27, 828, 13, 65, "Text"],
Cell[CellGroupData[{
Cell[1590, 44, 99, 1, 36, "Subsection"],
Cell[1692, 47, 405, 7, 29, "Text"],
Cell[2100, 56, 435, 14, 49, "Input"],
Cell[2538, 72, 266, 7, 31, "Input"],
Cell[2807, 81, 424, 15, 32, "Text"],
Cell[CellGroupData[{
Cell[3256, 100, 681, 19, 31, "Input"],
Cell[3940, 121, 1230, 34, 70, "Output"]
}, Open  ]],
Cell[5185, 158, 158, 2, 29, "Text"],
Cell[5346, 162, 467, 19, 32, "Text"],
Cell[CellGroupData[{
Cell[5838, 185, 947, 23, 31, "Input"],
Cell[6788, 210, 1255, 35, 70, "Output"]
}, Open  ]],
Cell[8058, 248, 2325, 72, 87, "Text"],
Cell[CellGroupData[{
Cell[10408, 324, 966, 26, 54, "Input"],
Cell[11377, 352, 1309, 36, 70, "Output"]
}, Open  ]],
Cell[12701, 391, 332, 6, 29, "Text"],
Cell[13036, 399, 2219, 65, 58, "Text"],
Cell[CellGroupData[{
Cell[15280, 468, 2703, 77, 50, "Input"],
Cell[17986, 547, 1890, 55, 70, "Output"]
}, Open  ]],
Cell[19891, 605, 94, 1, 29, "Text"],
Cell[19988, 608, 106, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[20119, 613, 2197, 66, 70, "Input"],
Cell[22319, 681, 937, 25, 70, "Output"]
}, Open  ]],
Cell[23271, 709, 1121, 42, 37, "Text"],
Cell[CellGroupData[{
Cell[24417, 755, 996, 29, 47, "Input"],
Cell[25416, 786, 1083, 30, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26536, 821, 467, 14, 31, "Input"],
Cell[27006, 837, 1089, 28, 70, "Output"]
}, Open  ]],
Cell[28110, 868, 125, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[28260, 873, 946, 22, 31, "Input"],
Cell[29209, 897, 848, 18, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30094, 920, 467, 13, 45, "Input"],
Cell[30564, 935, 433, 6, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[31046, 947, 288, 4, 41, "Section"],
Cell[CellGroupData[{
Cell[31359, 955, 107, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[31491, 960, 108, 1, 28, "Subsubsection"],
Cell[31602, 963, 723, 18, 49, "Text"],
Cell[32328, 983, 499, 12, 45, "Input"],
Cell[32830, 997, 344, 9, 32, "Text"],
Cell[CellGroupData[{
Cell[33199, 1010, 530, 15, 33, "Input"],
Cell[33732, 1027, 678, 16, 45, "Output"]
}, Open  ]],
Cell[34425, 1046, 3653, 87, 50, "Text"],
Cell[CellGroupData[{
Cell[38103, 1137, 1127, 24, 41, "Input"],
Cell[39233, 1163, 528, 13, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[39810, 1182, 104, 1, 28, "Subsubsection"],
Cell[39917, 1185, 123, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[40065, 1190, 445, 12, 31, "Input"],
Cell[40513, 1204, 610, 15, 45, "Output"]
}, Open  ]],
Cell[41138, 1222, 2926, 64, 32, "Text"],
Cell[CellGroupData[{
Cell[44089, 1290, 745, 20, 41, "Input"],
Cell[44837, 1312, 470, 12, 33, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[45368, 1331, 105, 1, 36, "Subsection"],
Cell[45476, 1334, 188, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[45689, 1342, 291, 7, 79, "Input"],
Cell[45983, 1351, 506, 10, 45, "Output"],
Cell[46492, 1363, 506, 10, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47035, 1378, 108, 1, 28, "Subsubsection"],
Cell[47146, 1381, 275, 5, 29, "Text"],
Cell[CellGroupData[{
Cell[47446, 1390, 695, 23, 50, "Input"],
Cell[48144, 1415, 653, 18, 45, "Output"]
}, Open  ]],
Cell[48812, 1436, 114, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[48951, 1441, 445, 12, 41, "Input"],
Cell[49399, 1455, 684, 19, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[50132, 1480, 108, 1, 28, "Subsubsection"],
Cell[50243, 1483, 234, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[50502, 1490, 403, 13, 31, "Input"],
Cell[50908, 1505, 571, 15, 45, "Output"]
}, Open  ]],
Cell[51494, 1523, 114, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[51633, 1528, 513, 13, 41, "Input"],
Cell[52149, 1543, 838, 20, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[53036, 1569, 103, 1, 28, "Subsubsection"],
Cell[53142, 1572, 186, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[53353, 1578, 393, 11, 31, "Input"],
Cell[53749, 1591, 683, 18, 45, "Output"]
}, Open  ]],
Cell[54447, 1612, 113, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[54585, 1617, 415, 12, 31, "Input"],
Cell[55003, 1631, 635, 17, 45, "Output"]
}, Open  ]],
Cell[55653, 1651, 129, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[55807, 1656, 802, 23, 52, "Input"],
Cell[56612, 1681, 467, 14, 45, "Output"],
Cell[57082, 1697, 413, 12, 45, "Output"]
}, Open  ]],
Cell[57510, 1712, 147, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[57682, 1719, 455, 14, 41, "Input"],
Cell[58140, 1735, 509, 12, 33, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[58710, 1754, 241, 3, 36, "Subsection"],
Cell[58954, 1759, 316, 5, 29, "Text"],
Cell[CellGroupData[{
Cell[59295, 1768, 1498, 36, 68, "Input"],
Cell[60796, 1806, 453, 15, 46, "Output"],
Cell[61252, 1823, 189, 4, 30, "Output"]
}, Open  ]],
Cell[61456, 1830, 191, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[61672, 1836, 1758, 45, 70, "Input"],
Cell[63433, 1883, 862, 23, 52, "Output"],
Cell[64298, 1908, 551, 11, 50, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[64898, 1925, 234, 3, 36, "Subsection"],
Cell[65135, 1930, 746, 21, 42, "Text"],
Cell[CellGroupData[{
Cell[65906, 1955, 502, 13, 45, "Input"],
Cell[66411, 1970, 977, 27, 52, "Output"]
}, Open  ]],
Cell[67403, 2000, 103, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[67531, 2005, 997, 26, 76, "Input"],
Cell[68531, 2033, 361, 5, 30, "Output"],
Cell[68895, 2040, 422, 6, 50, "Output"],
Cell[69320, 2048, 421, 6, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69778, 2059, 298, 4, 28, "Subsubsection"],
Cell[70079, 2065, 516, 12, 40, "Text"],
Cell[CellGroupData[{
Cell[70620, 2081, 786, 20, 47, "Input"],
Cell[71409, 2103, 1079, 32, 52, "Output"]
}, Open  ]],
Cell[72503, 2138, 173, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[72701, 2144, 1665, 44, 120, "Input"],
Cell[74369, 2190, 368, 5, 30, "Output"],
Cell[74740, 2197, 693, 17, 50, "Output"],
Cell[75436, 2216, 527, 11, 50, "Output"],
Cell[75966, 2229, 436, 6, 50, "Output"],
Cell[76405, 2237, 414, 5, 50, "Output"]
}, Open  ]],
Cell[76834, 2245, 241, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[77100, 2252, 583, 15, 33, "Input"],
Cell[77686, 2269, 1069, 29, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78792, 2303, 460, 14, 47, "Input"],
Cell[79255, 2319, 492, 13, 52, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[79796, 2338, 331, 4, 28, "Subsubsection"],
Cell[80130, 2344, 464, 14, 42, "Text"],
Cell[CellGroupData[{
Cell[80619, 2362, 661, 16, 47, "Input"],
Cell[81283, 2380, 1195, 34, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82515, 2419, 1084, 27, 76, "Input"],
Cell[83602, 2448, 379, 5, 30, "Output"],
Cell[83984, 2455, 454, 6, 50, "Output"],
Cell[84441, 2463, 444, 6, 50, "Output"]
}, Open  ]],
Cell[84900, 2472, 152, 3, 29, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[85101, 2481, 228, 3, 36, "Subsection"],
Cell[85332, 2486, 256, 5, 29, "Text"],
Cell[CellGroupData[{
Cell[85613, 2495, 589, 16, 31, "Input"],
Cell[86205, 2513, 771, 19, 47, "Output"]
}, Open  ]],
Cell[86991, 2535, 167, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[87183, 2541, 1718, 50, 79, "Input"],
Cell[88904, 2593, 625, 19, 63, "Output"],
Cell[89532, 2614, 560, 17, 52, "Output"]
}, Open  ]],
Cell[90107, 2634, 1417, 33, 29, "Text"],
Cell[CellGroupData[{
Cell[91549, 2671, 345, 10, 31, "Input"],
Cell[91897, 2683, 783, 17, 52, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[92729, 2706, 165, 2, 36, "Subsection"],
Cell[92897, 2710, 247, 5, 29, "Text"],
Cell[CellGroupData[{
Cell[93169, 2719, 251, 5, 31, "Input"],
Cell[93423, 2726, 1223, 37, 52, "Output"]
}, Open  ]],
Cell[94661, 2766, 1266, 25, 30, "Text"],
Cell[CellGroupData[{
Cell[95952, 2795, 571, 15, 33, "Input"],
Cell[96526, 2812, 1312, 38, 52, "Output"]
}, Open  ]],
Cell[97853, 2853, 197, 4, 29, "Text"],
Cell[98053, 2859, 161, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[98239, 2865, 335, 9, 31, "Input"],
Cell[98577, 2876, 528, 16, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99142, 2897, 143, 3, 28, "Subsubsection"],
Cell[99288, 2902, 126, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[99439, 2907, 280, 7, 31, "Input"],
Cell[99722, 2916, 738, 25, 52, "Output"]
}, Open  ]],
Cell[100475, 2944, 113, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[100613, 2949, 263, 6, 31, "Input"],
Cell[100879, 2957, 191, 5, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101107, 2967, 299, 7, 31, "Input"],
Cell[101409, 2976, 152, 4, 30, "Output"]
}, Open  ]],
Cell[101576, 2983, 352, 9, 29, "Text"],
Cell[CellGroupData[{
Cell[101953, 2996, 305, 7, 52, "Input"],
Cell[102261, 3005, 178, 4, 30, "Output"],
Cell[102442, 3011, 178, 4, 30, "Output"]
}, Open  ]],
Cell[102635, 3018, 135, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[102795, 3025, 297, 8, 31, "Input"],
Cell[103095, 3035, 153, 4, 30, "Output"]
}, Open  ]],
Cell[103263, 3042, 142, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[103430, 3049, 281, 7, 31, "Input"],
Cell[103714, 3058, 162, 4, 46, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
